@@ -30,15 +30,12 @@ Fl_Menu_Item menu_wide_menu[] = {
  {_("&Config"), 0,  0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Setup"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Transceiver"), 0,  (Fl_Callback*)cb_mnuConfigXcvr, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
- {_("XmlRpc"), 0,  (Fl_Callback*)cb_mnuXMLRPC, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
+// {_("XmlRpc"), 0,  (Fl_Callback*)cb_mnuXMLRPC, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("tcpip"), 0, (Fl_Callback*)cb_mnuTCPIP, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("PTT"), 0, (Fl_Callback*)cb_mnuPTT, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("AUX"), 0, (Fl_Callback*)cb_mnuAUX, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Polling"), 0, (Fl_Callback*)cb_Polling, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
- {0,0,0,0,0,0,0,0,0},
- {_("Start/Stop"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
- {_("Restore Freq/Mode"), 0,  (Fl_Callback*)cb_mnuRestoreData, 0, 6, FL_NORMAL_LABEL, 0, 14, 0},
- {_("Keep Freq/Mode"), 0,  (Fl_Callback*)cb_mnuKeepData, 0, 134, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Restore"), 0, (Fl_Callback*)cb_Restore, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {0,0,0,0,0,0,0,0,0},
  {_("UI"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Meter filtering"), 0,  (Fl_Callback*)cb_mnu_meter_filtering, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
@@ -83,6 +80,7 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 			scaleSmeter->box(FL_FLAT_BOX);
 			scaleSmeter->color((Fl_Color)246);
 			scaleSmeter->image(image_S60);
+			scaleSmeter->tooltip(_("S units meter"));
 
 			btnALC_SWR = new Fl_Button(xpos+1, ypos+1, 206, 20);
 			btnALC_SWR->tooltip(_("Press SWR / ALC"));
@@ -164,7 +162,7 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 			grpMeters->end();
 { // FreqDispA
 		FreqDispA = new cFreqControl(
-			grpMeters->x() + grpMeters->w() + 1, ypos, 290, 60, _("9"));
+			grpMeters->x() + grpMeters->w() + 1, ypos, 290, 60, _("10"));
 		FreqDispA->box(FL_DOWN_BOX);
 		FreqDispA->color(FL_BACKGROUND_COLOR);
 		FreqDispA->selection_color(FL_BACKGROUND_COLOR);
@@ -232,6 +230,13 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				btnB->callback((Fl_Callback*)cb_btnB);
 				btnB->value(useB);
 
+				labelMEMORY = new Fl_Box(
+					btnA->x(), btnA->y(), 69+2+69, btnA->h(), _("MEMORY"));
+				labelMEMORY->box(FL_DOWN_BOX);
+				labelMEMORY->color(FL_YELLOW);
+				labelMEMORY->align(FL_ALIGN_CENTER);
+				labelMEMORY->hide();
+
 				btnTune = new Fl_Button(
 					btnB->x() + btnB->w() + 2, btnB->y(), 69, 20, _("Tune"));
 				btnTune->tooltip(_("Momentary Tune"));
@@ -459,7 +464,7 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				sldrSQUELCH->textsize(12);
 				sldrSQUELCH->callback((Fl_Callback*)cb_sldrSQUELCH);
 				sldrSQUELCH->align(Fl_Align(FL_ALIGN_LEFT));
-				sldrSQUELCH->when(FL_WHEN_CHANGED);
+				sldrSQUELCH->when(FL_WHEN_RELEASE);
 				Fl_Group::current()->resizable(sldrSQUELCH);
 				sldrSQUELCH->reverse(true);
 
@@ -478,7 +483,7 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				sldrMICGAIN->textsize(12);
 				sldrMICGAIN->callback((Fl_Callback*)cb_sldrMICGAIN);
 				sldrMICGAIN->align(Fl_Align(FL_ALIGN_LEFT));
-				sldrMICGAIN->when(FL_WHEN_CHANGED);
+				sldrMICGAIN->when(FL_WHEN_RELEASE);
 				sldrMICGAIN->reverse(true);
 
 			grp_row2a->end();
@@ -508,7 +513,7 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				sldrIFSHIFT->textsize(12);
 				sldrIFSHIFT->callback((Fl_Callback*)cb_sldrIFSHIFT);
 				sldrIFSHIFT->align(Fl_Align(FL_ALIGN_CENTER|FL_ALIGN_INSIDE));
-				sldrIFSHIFT->when(FL_WHEN_CHANGED);
+				sldrIFSHIFT->when(FL_WHEN_RELEASE);
 				sldrIFSHIFT->reverse(true);
 
 				btnNR = new Fl_Light_Button(186, 128, 50, 18, _("NR"));
@@ -532,7 +537,7 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				sldrNR->textsize(12);
 				sldrNR->callback((Fl_Callback*)cb_sldrNR);
 				sldrNR->align(Fl_Align(FL_ALIGN_CENTER|FL_ALIGN_INSIDE));
-				sldrNR->when(FL_WHEN_CHANGED);
+				sldrNR->when(FL_WHEN_RELEASE);
 				Fl_Group::current()->resizable(sldrNR);
 				sldrNR->reverse(true);
 
@@ -564,10 +569,17 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				sldrNOTCH->textsize(12);
 				sldrNOTCH->callback((Fl_Callback*)cb_sldrNOTCH);
 				sldrNOTCH->align(Fl_Align(FL_ALIGN_CENTER|FL_ALIGN_INSIDE));
-				sldrNOTCH->when(FL_WHEN_CHANGED);
+				sldrNOTCH->when(FL_WHEN_RELEASE);
 				sldrNOTCH->reverse(true);
 
-				sldrRFGAIN = new Fl_Wheel_Value_Slider(421, 128, 128, 18, _("RF"));
+				btnAGC = new Fl_Light_Button(370, 128, 50, 18, _("AGC"));
+				btnAGC->tooltip(_("Automatic Gain Control"));
+				btnAGC->down_box(FL_THIN_DOWN_BOX);
+				btnAGC->value(0);
+				btnAGC->labelsize(12);
+				btnAGC->callback((Fl_Callback*)cb_btnAGC);
+
+				sldrRFGAIN = new Fl_Wheel_Value_Slider(421, 128, 128, 18);
 				sldrRFGAIN->tooltip(_("Adjust RF gain"));
 				sldrRFGAIN->type(5);
 				sldrRFGAIN->box(FL_THIN_DOWN_BOX);
@@ -583,7 +595,7 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				sldrRFGAIN->textsize(12);
 				sldrRFGAIN->callback((Fl_Callback*)cb_sldrRFGAIN);
 				sldrRFGAIN->align(Fl_Align(FL_ALIGN_LEFT));
-				sldrRFGAIN->when(FL_WHEN_CHANGED);
+				sldrRFGAIN->when(FL_WHEN_RELEASE);
 				Fl_Group::current()->resizable(sldrRFGAIN);
 				sldrRFGAIN->reverse(true);
 			grp_row2c->end();
@@ -592,7 +604,12 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 }
 			grp_row2d = new Fl_Group(552, 107, 182, 42);
 { // Power, Volume
-				sldrPOWER = new Fl_Wheel_Value_Slider(604, 108, 128, 18, _("PWR"));
+				btnPOWER = new Fl_Light_Button(552, 108, 50, 18, _("Pwr"));
+				btnPOWER->tooltip(_("Enable/Disable Power adjuster"));
+				btnPOWER->value(1);
+				btnPOWER-> callback((Fl_Callback*) cb_btnPOWER);
+
+				sldrPOWER = new Fl_Wheel_Value_Slider(604, 108, 128, 18, "");
 				sldrPOWER->tooltip(_("Adjust power level"));
 				sldrPOWER->type(5);
 				sldrPOWER->box(FL_THIN_DOWN_BOX);
@@ -608,7 +625,7 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				sldrPOWER->textsize(12);
 				sldrPOWER->callback((Fl_Callback*)cb_sldrPOWER);
 				sldrPOWER->align(Fl_Align(FL_ALIGN_LEFT));
-				sldrPOWER->when(FL_WHEN_CHANGED);
+				sldrPOWER->when(FL_WHEN_RELEASE);
 				sldrPOWER->reverse(true);
 
 				btnVol = new Fl_Light_Button(552, 128, 50, 18, _("Vol"));
@@ -634,7 +651,7 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				sldrVOLUME->textsize(12);
 				sldrVOLUME->callback((Fl_Callback*)cb_sldrVOLUME);
 				sldrVOLUME->align(Fl_Align(FL_ALIGN_CENTER|FL_ALIGN_INSIDE));
-				sldrVOLUME->when(FL_WHEN_CHANGED);
+				sldrVOLUME->when(FL_WHEN_RELEASE);
 				Fl_Group::current()->resizable(sldrVOLUME);
 				sldrVOLUME->reverse(true);
 
@@ -658,7 +675,7 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				sldrVOLUME->textsize(12);
 				sldrVOLUME->callback((Fl_Callback*)cb_sldrVOLUME);
 				sldrVOLUME->align(Fl_Align(FL_ALIGN_CENTER|FL_ALIGN_INSIDE));
-				sldrVOLUME->when(FL_WHEN_CHANGED);
+				sldrVOLUME->when(FL_WHEN_RELEASE);
 				Fl_Group::current()->resizable(sldrVOLUME);
 				sldrVOLUME->reverse(true);
 #endif
@@ -674,17 +691,18 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 	int tabs2_h = tabs_h - tab_v;
 
 	ypos = ytabs;
+
 	grpTABS = new Fl_Group(xpos, ypos, W, tabs_h);
-{
-	grpTABS->box(FL_FLAT_BOX);
+	{
+		grpTABS->box(FL_FLAT_BOX);
 
 		tabsGeneric = new Fl_Tabs(xpos, ypos, W, tabs_h);
-		ypos += tab_v;
-{
-		tabsGeneric->selection_color(FL_LIGHT1);
+		{
+			ypos += tab_v;
+			tabsGeneric->selection_color(FL_LIGHT1);
 
 			genericBands = new Fl_Group(xpos, ypos, W, tabs2_h, _("Bands"));
-{
+			{
 				btnBandSelect_1 = new Fl_Button(
 					xpos + 4, ypos + 10, 50, 22, _("1.8"));
 				btnBandSelect_1->tooltip(_("160m Band"));
@@ -777,22 +795,23 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				opSelect60->align(Fl_Align(FL_ALIGN_CENTER|FL_ALIGN_INSIDE));
 				opSelect60->when(FL_WHEN_RELEASE);
 				opSelect60->end();
-}
+
+				Fl_Box dmybx(xpos, ypos + tabs2_h - 2, W, 2, "");
+			genericBands->resizable(dmybx);
+			}
 			genericBands->end();
-			tabsGeneric->resizable(genericBands);
 
 			genericCW = new Fl_Group(xpos, ypos, W, tabs2_h, _("CW"));
-{
+			{
 				genericCW->color(FL_LIGHT1);
 				genericCW->selection_color(FL_LIGHT1);
-				genericCW->hide();
 
-				btnSpot = new Fl_Light_Button(13, 187, 54, 20, _("Spot"));
+				btnSpot = new Fl_Light_Button(13, ypos + 10, 54, 20, _("Spot"));
 				btnSpot->tooltip(_("Spot tone on/off"));
 				btnSpot->callback((Fl_Callback*)cb_btnSpot);
 				btnSpot->value(progStatus.cw_spot);
 
-				spnr_cw_spot_tone = new Hspinner(164, 187, 70, 20, _("Spot tone"));
+				spnr_cw_spot_tone = new Hspinner(164, ypos + 10, 70, 20, _("Spot tone"));
 				spnr_cw_spot_tone->tooltip(_("Spot volume"));
 				spnr_cw_spot_tone->type(FL_INT_INPUT);
 				spnr_cw_spot_tone->minimum(300);
@@ -803,7 +822,7 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				spnr_cw_spot_tone->align(Fl_Align(FL_ALIGN_LEFT));
 				spnr_cw_spot_tone->value(progStatus.cw_spot);
 
-				spnr_cw_weight = new Hspinner(299, 187, 70, 20, _("Weight"));
+				spnr_cw_weight = new Hspinner(299, ypos + 10, 70, 20, _("Weight"));
 				spnr_cw_weight->type(FL_INT_INPUT);
 				spnr_cw_weight->minimum(2.5);
 				spnr_cw_weight->maximum(4.5);
@@ -811,8 +830,9 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				spnr_cw_weight->callback((Fl_Callback*)cb_spnr_cw_weight);
 				spnr_cw_weight->align(Fl_Align(FL_ALIGN_LEFT));
 				spnr_cw_weight->value(progStatus.cw_weight);
+				spnr_cw_weight->tooltip(_("CW weight"));
 
-				spnr_cw_wpm = new Hspinner(435, 187, 70, 20, _("wpm"));
+				spnr_cw_wpm = new Hspinner(435, ypos + 10, 70, 20, _("wpm"));
 				spnr_cw_wpm->type(FL_INT_INPUT);
 				spnr_cw_wpm->minimum(5);
 				spnr_cw_wpm->maximum(80);
@@ -820,26 +840,31 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				spnr_cw_wpm->callback((Fl_Callback*)cb_spnr_cw_wpm);
 				spnr_cw_wpm->align(Fl_Align(FL_ALIGN_LEFT));
 				spnr_cw_wpm->value(progStatus.cw_wpm);
+				spnr_cw_wpm->tooltip(_("CW words per minute"));
 
-				btn_enable_keyer = new Fl_Check_Button(649, 190, 60, 15, _("Keyer"));
+				btn_enable_keyer = new Fl_Check_Button(649, ypos + 13, 60, 15, _("Keyer"));
 				btn_enable_keyer->tooltip(_("Enable internal keyer"));
 				btn_enable_keyer->down_box(FL_DOWN_BOX);
 				btn_enable_keyer->callback((Fl_Callback*)cb_btn_enable_keyer);
 				btn_enable_keyer->value(progStatus.enable_keyer);
-}
+
+				Fl_Box dmybx(xpos, ypos + tabs2_h - 2, W, 2, "");
+			genericCW->resizable(dmybx);
+			}
 			genericCW->end();
 
 			genericQSK = new Fl_Group(xpos, ypos, W, tabs2_h, _("QSK"));
+			{
 				genericQSK->color(FL_LIGHT1);
 				genericQSK->selection_color(FL_LIGHT1);
 				genericQSK->hide();
 
-				btnBreakIn = new Fl_Light_Button(13, 187, 54, 20, _("QSK"));
-				btnBreakIn->tooltip(_("Full break in on/off"));
+				btnBreakIn = new Fl_Button(xpos + 13, ypos + 10, 60, 20, _("QSK"));
+				btnBreakIn->tooltip(_("Full break in"));
 				btnBreakIn->callback((Fl_Callback*)cb_btnBreakIn);
 				btnBreakIn->value(progStatus.break_in);
 
-				spnr_cw_qsk = new Hspinner(170, 187, 70, 20, _("Bk-in Dly"));
+				spnr_cw_qsk = new Hspinner(xpos + 170, ypos + 10, 70, 20, _("Bk-in Dly"));
 				spnr_cw_qsk->tooltip(_("msec"));
 				spnr_cw_qsk->type(FL_INT_INPUT);
 				spnr_cw_qsk->minimum(0);
@@ -850,7 +875,7 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				spnr_cw_qsk->align(Fl_Align(FL_ALIGN_LEFT));
 				spnr_cw_qsk->value(progStatus.cw_qsk);
 
-				spnr_cw_delay = new Hspinner(330, 187, 100, 20, _("QSK delay"));
+				spnr_cw_delay = new Hspinner(xpos + 330, ypos + 10, 100, 20, _("QSK delay"));
 				spnr_cw_delay->tooltip(_("QSK delay (msec)"));
 				spnr_cw_delay->type(0);
 				spnr_cw_delay->minimum(30);
@@ -860,104 +885,119 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				spnr_cw_delay->value(progStatus.cw_delay);
 				spnr_cw_delay->align(Fl_Align(FL_ALIGN_LEFT));
 
+				Fl_Box dmybx(xpos, ypos + tabs2_h - 2, W, 2, "");
+			genericQSK->resizable(dmybx);
+			}
 			genericQSK->end();
 
 			genericVOX = new Fl_Group(xpos, ypos, W, tabs2_h, _("Vox"));
-{
-				genericVOX->hide();
+			{
 
-				spnr_vox_gain = new Hspinner(129, 187, 70, 20, _("gain"));
+				spnr_vox_gain = new Hspinner(129, ypos + 10, 70, 20, _("gain"));
 				spnr_vox_gain->type(FL_INT_INPUT);
 				spnr_vox_gain->minimum(0);
 				spnr_vox_gain->maximum(100);
 				spnr_vox_gain->step(1);
+				spnr_vox_gain->tooltip(_("VOX gain"));
 				spnr_vox_gain->callback((Fl_Callback*)cb_spnr_vox_gain);
 				spnr_vox_gain->align(Fl_Align(FL_ALIGN_LEFT));
 				spnr_vox_gain->value(progStatus.vox_gain);
 
-				spnr_anti_vox = new Hspinner(262, 187, 70, 20, _("anti"));
+				spnr_anti_vox = new Hspinner(262, ypos + 10, 70, 20, _("anti"));
 				spnr_anti_vox->type(FL_INT_INPUT);
 				spnr_anti_vox->minimum(0);
 				spnr_anti_vox->maximum(100);
 				spnr_anti_vox->step(1);
+				spnr_anti_vox->tooltip(_("Anti VOX gain"));
 				spnr_anti_vox->callback((Fl_Callback*)cb_spnr_anti_vox);
 				spnr_anti_vox->align(Fl_Align(FL_ALIGN_LEFT));
 				spnr_anti_vox->value(progStatus.vox_anti);
 
-				spnr_vox_hang = new Hspinner(396, 187, 100, 20, _("hang"));
+				spnr_vox_hang = new Hspinner(396, ypos + 10, 100, 20, _("hang"));
 				spnr_vox_hang->type(FL_INT_INPUT);
 				spnr_vox_hang->minimum(0);
 				spnr_vox_hang->maximum(100);
 				spnr_vox_hang->step(1);
+				spnr_vox_hang->tooltip(_("VOX hang time"));
 				spnr_vox_hang->callback((Fl_Callback*)cb_spnr_vox_hang);
 				spnr_vox_hang->align(Fl_Align(FL_ALIGN_LEFT));
 				spnr_vox_hang->value(progStatus.vox_hang);
 
-				btn_vox = new Fl_Light_Button(525, 187, 70, 20, _("VOX"));
+				btn_vox = new Fl_Light_Button(525, ypos + 10, 70, 20, _("VOX"));
 				btn_vox->callback((Fl_Callback*)cb_btn_vox);
 				btn_vox->value(progStatus.vox_onoff);
+				btn_vox->tooltip(_("VOX on/off"));
 
-				btn_vox_on_dataport = new Fl_Check_Button(610, 189, 70, 15, _("Data port"));
+				btn_vox_on_dataport = new Fl_Check_Button(610, ypos + 10, 70, 20, _("Data port"));
 				btn_vox_on_dataport->tooltip(_("Data port signal triggers VOX"));
 				btn_vox_on_dataport->down_box(FL_DOWN_BOX);
 				btn_vox_on_dataport->callback((Fl_Callback*)cb_btn_vox_on_dataport);
 				btn_vox_on_dataport->value(progStatus.vox_on_dataport);
-}
+
+				Fl_Box dmybx(xpos, ypos + tabs2_h - 2, W, 2, "");
+			genericVOX->resizable(dmybx);
+			}
 			genericVOX->end();
 
 			genericSpeech = new Fl_Group(xpos, ypos, W, tabs2_h, _("Spch"));
-{
-				genericSpeech->hide();
+			{
 
-				btnCompON = new Fl_Light_Button(230, 187, 70, 20, _("On"));
+				btnCompON = new Fl_Light_Button(230, ypos + 10, 70, 20, _("On"));
 				btnCompON->callback((Fl_Callback*)cb_btnCompON);
 				btnCompON->value(progStatus.compON);
+				btnCompON->tooltip(_("Compression on/off"));
 
-				spnr_compression = new Hspinner(138, 187, 70, 20, _("Comp"));
+				spnr_compression = new Hspinner(138, ypos + 10, 70, 20, _("Comp"));
 				spnr_compression->type(FL_INT_INPUT);
 				spnr_compression->minimum(0);
 				spnr_compression->maximum(100);
 				spnr_compression->step(1);
+				spnr_compression->tooltip(_("Compression level"));
 				spnr_compression->callback((Fl_Callback*)cb_spnr_compression);
 				spnr_compression->align(Fl_Align(FL_ALIGN_LEFT));
 				spnr_compression->value(progStatus.compression);
-}
+
+				Fl_Box dmybx(xpos, ypos + tabs2_h - 2, W, 2, "");
+			genericSpeech->resizable(dmybx);
+			}
 			genericSpeech->end();
 
 			genericRx = new Fl_Group(xpos, ypos, W, tabs2_h, _("RX"));
-{
-				genericRx->hide();
+			{
 
-				cbo_nb_level = new Fl_ComboBox(90, 187, 80, 20, _("NB level"));
-				cbo_nb_level->tooltip(_("Select Transceiver"));
-				cbo_nb_level->box(FL_DOWN_BOX);
-				cbo_nb_level->color(FL_BACKGROUND_COLOR);
-				cbo_nb_level->selection_color(FL_BACKGROUND_COLOR);
-				cbo_nb_level->labeltype(FL_NORMAL_LABEL);
-				cbo_nb_level->labelfont(0);
-				cbo_nb_level->labelsize(14);
-				cbo_nb_level->labelcolor(FL_FOREGROUND_COLOR);
-				cbo_nb_level->callback((Fl_Callback*)cb_cbo_nb_level);
-				cbo_nb_level->align(Fl_Align(FL_ALIGN_LEFT));
-				cbo_nb_level->when(FL_WHEN_RELEASE);
-				cbo_nb_level->index(progStatus.nb_level);
-				cbo_nb_level->end();
+				sldr_nb_level = new Fl_Wheel_Value_Slider(90, ypos + 10, 180, 20, _("NB level"));
+				sldr_nb_level->tooltip(_("Noise Blanker level"));
+				sldr_nb_level->type(5);
+				sldr_nb_level->box(FL_THIN_DOWN_BOX);
+				sldr_nb_level->color(FL_BACKGROUND_COLOR);
+				sldr_nb_level->selection_color(FL_BACKGROUND_COLOR);
+				sldr_nb_level->labeltype(FL_NORMAL_LABEL);
+				sldr_nb_level->labelfont(0);
+				sldr_nb_level->labelsize(14);
+				sldr_nb_level->labelcolor(FL_FOREGROUND_COLOR);
+				sldr_nb_level->minimum(0);
+				sldr_nb_level->maximum(0);
+				sldr_nb_level->step(1);
+				sldr_nb_level->callback((Fl_Callback*)cb_sldr_nb_level);
+				sldr_nb_level->align(Fl_Align(FL_ALIGN_LEFT));
+				sldr_nb_level->when(FL_WHEN_RELEASE);
+				sldr_nb_level->value(progStatus.nb_level);
 
-				cbo_agc_level = new Fl_ComboBox(244, 187, 80, 20, _("AGC"));
-				cbo_agc_level->tooltip(_("Select Transceiver"));
-				cbo_agc_level->box(FL_DOWN_BOX);
-				cbo_agc_level->color(FL_BACKGROUND_COLOR);
-				cbo_agc_level->selection_color(FL_BACKGROUND_COLOR);
-				cbo_agc_level->labeltype(FL_NORMAL_LABEL);
-				cbo_agc_level->labelfont(0);
-				cbo_agc_level->labelsize(14);
-				cbo_agc_level->labelcolor(FL_FOREGROUND_COLOR);
-				cbo_agc_level->callback((Fl_Callback*)cb_cbo_agc_level);
-				cbo_agc_level->align(Fl_Align(FL_ALIGN_LEFT));
-				cbo_agc_level->when(FL_WHEN_RELEASE);
-				cbo_agc_level->end();
+//				cbo_agc_level = new Fl_ComboBox(244, ypos + 10, 80, 20, _("AGC"));
+//				cbo_agc_level->tooltip(_("AGC level"));
+//				cbo_agc_level->box(FL_DOWN_BOX);
+//				cbo_agc_level->color(FL_BACKGROUND_COLOR);
+//				cbo_agc_level->selection_color(FL_BACKGROUND_COLOR);
+//				cbo_agc_level->labeltype(FL_NORMAL_LABEL);
+//				cbo_agc_level->labelfont(0);
+//				cbo_agc_level->labelsize(14);
+//				cbo_agc_level->labelcolor(FL_FOREGROUND_COLOR);
+//				cbo_agc_level->callback((Fl_Callback*)cb_cbo_agc_level);
+//				cbo_agc_level->align(Fl_Align(FL_ALIGN_LEFT));
+//				cbo_agc_level->when(FL_WHEN_RELEASE);
+//				cbo_agc_level->end();
 
-				spnr_bpf_center = new Hspinner(474, 187, 96, 20, _("BPF Center Freq"));
+				spnr_bpf_center = new Hspinner(474, ypos + 10, 96, 20, _("BPF Center Freq"));
 				spnr_bpf_center->tooltip(_("Bandpass Filter Center Freq"));
 				spnr_bpf_center->type(FL_INT_INPUT);
 				spnr_bpf_center->minimum(600);
@@ -968,26 +1008,28 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				spnr_bpf_center->align(Fl_Align(36));
 				spnr_bpf_center->value(progStatus.bpf_center);
 
-				btn_use_bpf_center = new Fl_Check_Button(627, 189, 50, 15, _("On"));
+				btn_use_bpf_center = new Fl_Check_Button(627, ypos + 10, 50, 20, _("On"));
 				btn_use_bpf_center->tooltip(_("Use Filter Center Freq Adj"));
 				btn_use_bpf_center->down_box(FL_DOWN_BOX);
 				btn_use_bpf_center->value(1);
 				btn_use_bpf_center->callback((Fl_Callback*)cb_btn_use_bpf_center);
 				btn_use_bpf_center->value(progStatus.use_bpf_center);
-}
+
+				Fl_Box dmybx(xpos, ypos + tabs2_h - 2, W, 2, "");
+			genericRx->resizable(dmybx);
+			}
 			genericRx->end();
 
 			genericMisc = new Fl_Group(xpos, ypos, W, tabs2_h, _("Misc"));
-{
-				genericMisc->hide();
+			{
 
-				spnr_vfo_adj = new Hspinner(60, 187, 96, 20, _("Vfo Adj"));
+				spnr_vfo_adj = new Hspinner(60, ypos + 10, 96, 20, _("Vfo Adj"));
 				spnr_vfo_adj->type(FL_INT_INPUT);
 				spnr_vfo_adj->callback((Fl_Callback*)cb_spnr_vfo_adj);
 				spnr_vfo_adj->align(Fl_Align(36));
 				spnr_vfo_adj->value(progStatus.vfo_adj);
 
-				spnr_line_out = new Hspinner(225, 187, 70, 20, _("line out"));
+				spnr_line_out = new Hspinner(225, ypos + 10, 70, 20, _("line out"));
 				spnr_line_out->type(FL_INT_INPUT);
 				spnr_line_out->minimum(0);
 				spnr_line_out->maximum(100);
@@ -997,31 +1039,66 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				spnr_line_out->align(Fl_Align(FL_ALIGN_LEFT));
 				spnr_line_out->value(progStatus.line_out);
 
-				btnSpecial = new Fl_Light_Button(300, 187, 74, 20, _("Special"));
+				btnSpecial = new Fl_Light_Button(300, ypos + 10, 74, 20, _("Special"));
 				btnSpecial->callback((Fl_Callback*)cb_btnSpecial);
 
-				btn_ext_tuner = new Fl_Check_Button(380, 189, 80, 15, _("Ext tuner"));
+				btn_ext_tuner = new Fl_Check_Button(380, ypos + 10, 80, 20, _("Ext tuner"));
 				btn_ext_tuner->tooltip(_("use external auto tuner"));
 				btn_ext_tuner->down_box(FL_DOWN_BOX);
 				btn_ext_tuner->callback((Fl_Callback*)cb_btn_ext_tuner);
 				btn_ext_tuner->value(progStatus.external_tuner);
 
-				btn_xcvr_auto_on = new Fl_Check_Button(470, 189, 95, 15, _("Rig autOn"));
+				btn_xcvr_auto_on = new Fl_Check_Button(470, ypos + 10, 95, 20, _("Rig autOn"));
 				btn_xcvr_auto_on->tooltip(_("Auto Turn Rig On with Flrig startup"));
 				btn_xcvr_auto_on->down_box(FL_DOWN_BOX);
 				btn_xcvr_auto_on->callback((Fl_Callback*)cb_btn_xcvr_auto_on);
 				btn_xcvr_auto_on->value(progStatus.xcvr_auto_on);
 
-				btn_xcvr_auto_off = new Fl_Check_Button(607, 189, 95, 15, _("Rig autOff"));
+				btn_xcvr_auto_off = new Fl_Check_Button(607, ypos + 10, 95, 20, _("Rig autOff"));
 				btn_xcvr_auto_off->tooltip(_("Auto Turn Rig Off with Flrig exit"));
 				btn_xcvr_auto_off->down_box(FL_DOWN_BOX);
 				btn_xcvr_auto_off->callback((Fl_Callback*)cb_btn_xcvr_auto_off);
 				btn_xcvr_auto_off->value(progStatus.xcvr_auto_off);
-}
+
+				Fl_Box dmybx(xpos, ypos + tabs2_h - 2, W, 2, "");
+			genericMisc->resizable(dmybx);
+			}
 			genericMisc->end();
 
+			genericUser = new Fl_Group(xpos, ypos, W, tabs2_h, _("User"));
+			{
+
+				btnUser1 = new Fl_Button(5, ypos + 15, 88, 24, "USER 1");
+				btnUser1->callback((Fl_Callback*)cb_btnUser, (void*)1);
+
+				btnUser2 = new Fl_Button(95, ypos + 15, 88, 24, "USER 2");
+				btnUser2->callback((Fl_Callback*)cb_btnUser, (void*)2);
+
+				btnUser3 = new Fl_Button(185, ypos + 15, 88, 24, "USER 3");
+				btnUser3->callback((Fl_Callback*)cb_btnUser, (void*)3);
+
+				btnUser4 = new Fl_Button(275, ypos + 15, 88, 24, "USER 4");
+				btnUser4->callback((Fl_Callback*)cb_btnUser, (void*)4);
+
+				btnUser5 = new Fl_Button(365, ypos + 15, 88, 24, "USER 5");
+				btnUser5->callback((Fl_Callback*)cb_btnUser, (void*)5);
+
+				btnUser6 = new Fl_Button(455, ypos + 15, 88, 24, "USER 6");
+				btnUser6->callback((Fl_Callback*)cb_btnUser, (void*)6);
+
+				btnUser7 = new Fl_Button(545, ypos + 15, 88, 24, "USER 7");
+				btnUser7->callback((Fl_Callback*)cb_btnUser, (void*)7);
+
+				btnUser8 = new Fl_Button(635, ypos + 15, 88, 24, "USER 8");
+				btnUser8->callback((Fl_Callback*)cb_btnUser, (void*)8);
+
+				Fl_Box dmybx(xpos, ypos + tabs2_h - 2, W, 2, "");
+			genericUser->resizable(dmybx);
+			}
+			genericUser->end();
+
 			genericRXB = new Fl_Group(xpos, ypos, W, tabs2_h, _("RIT/XIT/BFO"));
-{
+			{
 				genericRXB->hide();
 
 				cntRIT = new Hspinner(218, 187, 60, 20, _("Rit"));
@@ -1054,11 +1131,11 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				cntBFO->value(600);
 				cntBFO->callback((Fl_Callback*)cb_cntBFO);
 				cntBFO->align(Fl_Align(FL_ALIGN_RIGHT));
-}
+			}
 			genericRXB->end();
 
 			genericAux = new Fl_Group(xpos, ypos, W, tabs2_h, _("Aux"));
-{
+			{
 				genericAux->hide();
 
 				boxControl = new Fl_Box(57, 187, 130, 20, _("Auxilliary Controls:"));
@@ -1085,20 +1162,23 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				btnDataPort->labelsize(12);
 				btnDataPort->callback((Fl_Callback*)cb_btnDataPort);
 				btnDataPort->value(progStatus.data_port);
-}
+			}
 			genericAux->end();
-}
+
+		}
 		tabsGeneric->end();
+
+		tabsGeneric->resizable(genericBands);
 		tabsGeneric->hide();
 
 		ypos = ytabs;
 		tabs550 = new Fl_Tabs(xpos, ypos, W, tabs_h);
 		ypos += 24;
-{
+		{
 			tabs550->selection_color(FL_LIGHT1);
 
 			tt550_CW = new Fl_Group(xpos, ypos, W, tabs2_h, _("CW"));
-{
+			{
 				tt550_CW->color(FL_LIGHT1);
 				tt550_CW->selection_color(FL_LIGHT1);
 
@@ -1113,10 +1193,11 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				spnr_tt550_cw_wpm->value(progStatus.tt550_cw_wpm);
 
 				spnr_tt550_cw_weight = new Hspinner(187, 187, 67, 20, _("Weight"), 15);
-				spnr_tt550_cw_weight->type(FL_INT_INPUT);
+				spnr_tt550_cw_weight->type(FL_FLOAT_INPUT);
 				spnr_tt550_cw_weight->minimum(0.75);
 				spnr_tt550_cw_weight->maximum(1.5);
 				spnr_tt550_cw_weight->step(0.05);
+				spnr_tt550_cw_weight->format("%.2f");
 				spnr_tt550_cw_weight->value(20);
 				spnr_tt550_cw_weight->callback((Fl_Callback*)cb_spnr_tt550_cw_weight);
 				spnr_tt550_cw_weight->align(Fl_Align(FL_ALIGN_LEFT));
@@ -1160,12 +1241,12 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				btn_tt550_enable_keyer->down_box(FL_DOWN_BOX);
 				btn_tt550_enable_keyer->callback((Fl_Callback*)cb_btn_tt550_enable_keyer);
 				btn_tt550_enable_keyer->value(progStatus.tt550_enable_keyer);
-}
+			}
 			tt550_CW->end();
 			tabs550->resizable(tt550_CW);
 
 			tt550_VOX = new Fl_Group(xpos, ypos, W, tabs2_h, _("Vox"));
-{
+			{
 				tt550_VOX->hide();
 
 				spnr_tt550_vox_gain = new Hspinner(101, 187, 79, 20, _("gain"), 15);
@@ -1198,11 +1279,11 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				btn_tt550_vox = new Fl_Light_Button(633, 187, 78, 20, _("VOX"));
 				btn_tt550_vox->callback((Fl_Callback*)cb_btn_tt550_vox);
 				btn_tt550_vox->value(progStatus.tt550_vox_onoff);
-}
+			}
 			tt550_VOX->end();
 
 			tt550_Speech = new Fl_Group(xpos, ypos, W, tabs2_h, _("Spch"));
-{
+			{
 				tt550_Speech->hide();
 
 				btn_tt550_CompON = new Fl_Light_Button(559, 187, 78, 20, _("On"));
@@ -1228,11 +1309,11 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				spnr_tt550_mon_vol->callback((Fl_Callback*)cb_spnr_tt550_mon_vol);
 				spnr_tt550_mon_vol->align(Fl_Align(FL_ALIGN_LEFT));
 				spnr_tt550_mon_vol->value(progStatus.tt550_mon_vol);
-}
+			}
 			tt550_Speech->end();
 
 			tt550_Audio = new Fl_Group(xpos, ypos, W, tabs2_h, _("Audio"));
-{
+			{
 				tt550_Audio->hide();
 
 				spnr_tt550_line_out = new Hspinner(296, 187, 77, 20, _("line out"), 15);
@@ -1250,11 +1331,11 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				btnAccInp->down_box(FL_DOWN_BOX);
 				btnAccInp->callback((Fl_Callback*)cb_btnAccInp);
 				btnAccInp->value(progStatus.tt550_use_line_in);
-}
+			}
 			tt550_Audio->end();
 
 			tt550_Rx = new Fl_Group(xpos, ypos, W, tabs2_h, _("RX"));
-{
+			{
 				tt550_Rx->hide();
 
 				cbo_tt550_nb_level = new Fl_ComboBox(179, 187, 89, 20, _("NB level"));
@@ -1293,14 +1374,15 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				spnr_tt550_vfo_adj->minimum(-100);
 				spnr_tt550_vfo_adj->maximum(100);
 				spnr_tt550_vfo_adj->type(FL_FLOAT_INPUT);
-				spnr_tt550_vfo_adj->step(0.1);
+				spnr_tt550_vfo_adj->step(0.02);
+				spnr_tt550_vfo_adj->format("%.2f");
 				spnr_tt550_vfo_adj->value(progStatus.vfo_adj);
 
-}
+			}
 			tt550_Rx->end();
 
 			tt550_Tx = new Fl_Group(xpos, ypos, W, tabs2_h, _("TX"));
-{
+			{
 				tt550_Tx->hide();
 
 				btn_tt550_enable_xmtr = new Fl_Check_Button(111, 187, 78, 16, _("Tx ON"));
@@ -1340,11 +1422,11 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				btn_tt550_use_xmt_bw->callback((Fl_Callback*)cb_btn_tt550_use_xmt_bw);
 				btn_tt550_use_xmt_bw->align(Fl_Align(FL_ALIGN_RIGHT));
 				btn_tt550_use_xmt_bw->value(progStatus.tt550_use_xmt_bw);
-}
+			}
 			tt550_Tx->end();
 
 			tt550_302A = new Fl_Group(xpos, ypos, W, tabs2_h, _("302-A"));
-{
+			{
 				tt550_302A->hide();
 
 				spnr_tt550_keypad_time_out = new Hspinner(106, 187, 134, 20, _("Time out"));
@@ -1373,11 +1455,11 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				sel_tt550_encoder_step->callback((Fl_Callback*)cb_sel_tt550_encoder_step);
 				sel_tt550_encoder_step->add("1|10|100|1 K|10 K");
 				sel_tt550_encoder_step->value(progStatus.tt550_encoder_step);
-}
+			}
 			tt550_302A->end();
 
 			tt550_302B = new Fl_Group(xpos, ypos, W, tabs2_h, _("302-B"));
-{
+			{
 				tt550_302B->hide();
 
 				sel_tt550_F1_func = new Fl_Choice(168, 187, 111, 20, _("F1"));
@@ -1400,16 +1482,54 @@ Fl_Group *wide_main_group(int X, int Y, int W, int H)
 				sel_tt550_F3_func->callback((Fl_Callback*)cb_sel_tt550_F3_func);
 				sel_tt550_F3_func->add("None|Clear|CW++|CW--|Band++|Band--|Step++|Step--");
 				sel_tt550_F3_func->value(progStatus.tt550_F3_func);
-}
+			}
 			tt550_302B->end();
-}
+
+			tt550_AT = new Fl_Group(xpos, ypos, W, tabs2_h, _("AT"));
+			{
+				tt550_AT_inline = new Fl_Light_Button(
+					5, tt550_AT->y() + 15, 80, 22, _("Inline"));
+				tt550_AT_inline->tooltip(_("Enabled - autotune\nDisabled - bypass"));
+				tt550_AT_inline->callback((Fl_Callback*)cb_AT_bypass);
+
+				tt550_AT_Z = new Fl_Light_Button(140, tt550_AT->y() + 15, 55, 22, _("Z hi"));
+				tt550_AT_Z->tooltip(_("Hi / Lo Impedance network"));
+				tt550_AT_Z->callback((Fl_Callback*)cb_AT_Z);
+
+				tt550_AT_capUP = new Fl_Button(200, tt550_AT->y() + 15, 50, 22, _("C >"));
+				tt550_AT_capUP->tooltip(_("Increase C"));
+				tt550_AT_capUP->callback((Fl_Callback*)cb_AT_capUP);
+
+				tt550_AT_capDN = new Fl_Button(255, tt550_AT->y() + 15, 50, 22, _("C <"));
+				tt550_AT_capDN->tooltip(_("Decrease C"));
+				tt550_AT_capDN->callback((Fl_Callback*)cb_AT_capDN);
+
+				tt550_AT_indUP = new Fl_Button(310, tt550_AT->y() + 15, 50, 22, _("L >"));
+				tt550_AT_indUP->tooltip(_("Increase L"));
+				tt550_AT_indUP->callback((Fl_Callback*)cb_AT_indUP);
+
+				tt550_AT_indDN = new Fl_Button(365, tt550_AT->y() + 15, 50, 22, _("L <"));
+				tt550_AT_indDN->tooltip(_("Decrease L"));
+				tt550_AT_indDN->callback((Fl_Callback*)cb_AT_indDN);
+
+				tt550_Nsamples = new Fl_Simple_Counter(
+					RIGHT_OF(tt550_AT_indDN) + 5, tt550_AT->y() + 15, 50, 22, _("N"));
+				tt550_Nsamples->tooltip(_("Fwd/Rev Pwr detect over # samples"));
+				tt550_Nsamples->align(FL_ALIGN_RIGHT);
+				tt550_Nsamples->step(1);
+				tt550_Nsamples->minimum(1);
+				tt550_Nsamples->maximum(FPLEN);
+				tt550_Nsamples->value(progStatus.tt550_Nsamples);
+				tt550_Nsamples->callback((Fl_Callback*)cb_tt550_Nsamples);
+			}
+			tt550_AT->end();
+		}
 		tabs550->end();
 		tabs550->hide();
-
+	}
 	grpTABS->end();
-
 	grpTABS->hide();
-}
+
 	g->end();
 	g->resizable(grpTABS);
 
@@ -1428,9 +1548,14 @@ Fl_Double_Window* Wide_rig_window() {
 
 		wide_menu = new Fl_Menu_Bar(0, 0, mainW - 64, menuH);
 		wide_menu->textsize(12);
-		progStatus.tooltips ? (&menu_wide_menu[6])->set() : (&menu_wide_menu[6])->clear();
 		wide_menu->menu(menu_wide_menu);
 
+		Fl_Menu_Item * mnu = getMenuItem(_("Tooltips"), menu_wide_menu);
+		if (mnu) {
+			progStatus.tooltips ? mnu->set() : mnu->clear();
+			mnuTooltips = mnu;
+		}
+
 		Fl_Group *mnu_box = new Fl_Group(mainW - 64, 0, 64, menuH);
 		mnu_box->box(FL_UP_BOX);
 
@@ -1454,15 +1579,27 @@ Fl_Double_Window* Wide_rig_window() {
 
 	grp_menu->end();
 
-	mnuRestoreData = (menu_wide_menu+12);
-	mnuKeepData = (menu_wide_menu+13);
-	mnuTooltips = (menu_wide_menu+17);
-
-	btnInitializing = new Fl_Button(0,menuH,10,10);
-	btnInitializing->hide();
-
 	main_group = wide_main_group(0, menuH, mainW, mainH - menuH);
-	main_group->show();
+	main_group->hide();
+
+	grpInitializing = new Fl_Group(0, menuH, mainW, mainH - menuH, "");
+
+		grpInitializing->box(FL_FLAT_BOX);
+		grpInitializing->color(FL_LIGHT2);
+
+		progress = new Fl_Progress(
+			mainW / 4, grpInitializing->y() + grpInitializing->h() / 2,
+			mainW / 2, 20, "Initializing");
+		progress->maximum(100);
+		progress->minimum(0);
+		progress->labelcolor(FL_RED);
+		progress->labelsize(14);
+		progress->align(Fl_Align(FL_ALIGN_TOP));
+		progress->selection_color(FL_GREEN);
+
+		grpInitializing->end();
+
+	grpInitializing->show();
 
 	w->resizable(main_group);
 
