@@ -73,7 +73,7 @@ public:
 	int  get_split();
 
 	bool canswap() { return true; }
-	void swapvfos();
+	bool ICswap() { return true; }
 
 	int  get_mic_gain();
 	void set_mic_gain(int val);
@@ -91,10 +91,13 @@ public:
 
 	void set_noise_reduction_val(int val);
 	int  get_noise_reduction_val();
-	void set_compression();
+	void set_compression(int, int);
 	void get_comp_min_max_step(int &min, int &max, int &step) {
 		min = 0; max = 10; step = 1; }
 
+	void set_PTT_control(int val);
+	int  get_PTT();
+
 };
 
 
