@@ -109,19 +109,28 @@ public:
 
 	int  get_smeter();
 	int  get_swr();
+
 	int  get_power_out();
-//	int  get_power_control();
-	void set_volume_control(int val);
-	int  get_volume_control();
+
+	int  get_power_control();
 	void set_power_control(double val);
 	void get_pc_min_max_step(double &min, double &max, double &step) {
 		min = 5; max = 100; step = 1; }
+
+	void set_volume_control(int val);
+	int  get_volume_control();
+
 	void set_PTT_control(int val);
+	int  get_PTT();
+
 	void tune_rig();
+
 	void set_attenuator(int val);
-//	int  get_attenuator() {return 0}
+	int  get_attenuator();
+
 	void set_preamp(int val);
-//	int  get_preamp();
+	int  get_preamp();
+
 	void set_if_shift(int val);
 	bool get_if_shift(int &val);
 	void get_if_min_max_step(int &min, int &max, int &step);
@@ -129,14 +138,18 @@ public:
 //	void set_notch(bool on, int val);
 //	bool get_notch(int &val);
 //	void get_notch_min_max_step(int &min, int &max, int &step);
+
 	void set_noise(bool b);
 	void set_mic_gain(int val);
-//	int  get_mic_gain();
+	int  get_mic_gain();
+
 	void set_mic_line(int val);
 	void get_mic_min_max_step(int &min, int &max, int &step);
+
 	void set_rf_gain(int val);
 	int  get_rf_gain();
 	void get_rf_min_max_step(int &min, int &max, int &step);
+
 	int  adjust_bandwidth(int m);
 	int  def_bandwidth(int m);
 
@@ -175,13 +188,22 @@ public:
 	void set_vox_hang();
 	void set_aux_hang();
 	void set_mon_vol();
-	void set_compression();
+	void set_compression(int, int);
 	void set_squelch_level();
 	void tuner_bypass();
 	void enable_xmtr();
 	void enable_tloop();
 	void set_nb_level();
 
+// TT-550 / at-11 internal tuner i/o commands
+	void at11_bypass();
+	void at11_autotune();
+	void at11_cap_up();
+	void at11_cap_dn();
+	void at11_ind_up();
+	void at11_ind_dn();
+	void at11_loZ();
+	void at11_hiZ();
 
 };
 
