@@ -47,6 +47,8 @@
 #include <FL/Fl_Value_Input.H>
 #include <FL/Fl_Round_Button.H>
 #include <FL/Fl_Counter.H>
+#include <FL/Fl_Simple_Counter.H>
+#include <FL/Fl_Progress.H>
 
 #include "flinput2.h"
 #include "Fl_SigBar.h"
@@ -88,6 +90,7 @@ extern Fl_Light_Button *btnA;
 extern Fl_Button *btn_K3_swapAB;
 extern Fl_Button *btn_KX3_swapAB;
 extern Fl_Light_Button *btnB;
+extern Fl_Box *labelMEMORY;
 extern Fl_Button *btnTune;
 extern Fl_Box *bx_row0_expander;
 extern Fl_Button *btn_show_controls;
@@ -125,12 +128,14 @@ extern Fl_Box *bx_sep2b;
 extern Fl_Group *grp_row2c;
 extern Fl_Light_Button *btnNotch;
 extern Fl_Wheel_Value_Slider *sldrNOTCH;
+extern Fl_Light_Button *btnAGC;
 extern Fl_Wheel_Value_Slider *sldrRFGAIN;
 extern Fl_Box *bx_sep2c;
 extern Fl_Group *grp_row2d;
 
 extern Fl_Wheel_Value_Slider *sldrPOWER;
 
+extern Fl_Light_Button *btnPOWER;
 extern Hspinner *spnrPOWER;
 extern Hspinner *spnrVOLUME;
 extern Hspinner *spnrRFGAIN;
@@ -162,10 +167,21 @@ extern Fl_Group *genericCW;
 extern Fl_Light_Button *btnSpot;
 
 extern Fl_Group *genericQSK;
-extern Fl_Light_Button *btnBreakIn;
+extern Fl_Button *btnBreakIn;
 extern Hspinner *spnr_cw_delay;
 extern Hspinner *cnt_cw_qsk;
 
+extern Fl_Group  *genericUser;
+extern Fl_Button *btnUser1;
+extern Fl_Button *btnUser2;
+extern Fl_Button *btnUser3;
+extern Fl_Button *btnUser4;
+extern Fl_Button *btnUser5;
+extern Fl_Button *btnUser6;
+extern Fl_Button *btnUser7;
+extern Fl_Button *btnUser8;
+extern Fl_Output * cmdResponse;
+
 extern Hspinner *spnr_cw_spot_tone;
 extern Hspinner *spnr_cw_qsk;
 extern Hspinner *spnr_cw_weight;
@@ -182,8 +198,8 @@ extern Fl_Group *genericSpeech;
 extern Fl_Light_Button *btnCompON;
 extern Hspinner *spnr_compression;
 extern Fl_Group *genericRx;
-extern Fl_ComboBox *cbo_nb_level;
-extern Fl_ComboBox *cbo_agc_level;
+extern Fl_Wheel_Value_Slider *sldr_nb_level;
+//extern Fl_ComboBox *cbo_agc_level;
 extern Hspinner *spnr_bpf_center;
 extern Fl_Check_Button *btn_use_bpf_center;
 extern Fl_Group *genericMisc;
@@ -241,9 +257,12 @@ extern Fl_Group *tt550_302B;
 extern Fl_Choice *sel_tt550_F1_func;
 extern Fl_Choice *sel_tt550_F2_func;
 extern Fl_Choice *sel_tt550_F3_func;
+extern Fl_Light_Button *tt550_AT_inline;
+extern Fl_Light_Button *tt550_AT_Z;
 
 extern Fl_Group  *main_group;
-extern Fl_Button *btnInitializing;
+extern Fl_Group  *grpInitializing;
+extern Fl_Progress *progress;
 
 extern Fl_Menu_Item *mnuExit;
 extern Fl_Menu_Item *mnuConfig;
@@ -310,6 +329,24 @@ extern Fl_Tabs *tabsConfig;
 extern Fl_Group *tabPrimary;
 extern Fl_ComboBox *selectRig;
 
+extern Fl_Group *tabCmds;
+extern Fl_Input2 * cmdlbl1;
+extern Fl_Input2 * cmdlbl2;
+extern Fl_Input2 * cmdlbl3;
+extern Fl_Input2 * cmdlbl4;
+extern Fl_Input2 * cmdlbl5;
+extern Fl_Input2 * cmdlbl6;
+extern Fl_Input2 * cmdlbl7;
+extern Fl_Input2 * cmdlbl8;
+extern Fl_Input2 * cmdtext1;
+extern Fl_Input2 * cmdtext2;
+extern Fl_Input2 * cmdtext3;
+extern Fl_Input2 * cmdtext4;
+extern Fl_Input2 * cmdtext5;
+extern Fl_Input2 * cmdtext6;
+extern Fl_Input2 * cmdtext7;
+extern Fl_Input2 * cmdtext8;
+
 extern Fl_Counter *cntRigCatRetries;
 extern Fl_Counter *cntRigCatTimeout;
 extern Fl_Counter *cntRigCatWait;
@@ -336,13 +373,16 @@ extern Fl_Check_Button *btnUSBaudio;
 extern Fl_Check_Button *btn_key_fldigi;
 extern Fl_Group *tabPTT;
 extern Fl_ComboBox *selectSepPTTPort;
-extern Fl_Round_Button *btnSepRTSptt;
+extern Fl_Check_Button *btnSep_SCU_17;
+extern Fl_Check_Button *btnSepRTSptt;
 extern Fl_Check_Button *btnSepRTSplus;
-extern Fl_Round_Button *btnSepDTRptt;
+extern Fl_Check_Button *btnSepDTRptt;
 extern Fl_Check_Button *btnSepDTRplus;
 extern Fl_Group *tabAux;
 extern Fl_ComboBox *selectAuxPort;
+extern Fl_Check_Button *btnAux_SCU_17;
 extern Fl_Group *tabPolling;
+extern Fl_Group *tabRestore;
 extern Fl_Group *tabTCPIP;
 extern Fl_Group *tabXMLRPC;
 
@@ -376,8 +416,12 @@ extern Fl_Output *txt_response;
 extern Fl_Box *box_xcvr_connect;
 extern Fl_Box *box_fldigi_connect;
 extern Fl_Box *box_tcpip_connect;
-extern Fl_Button *btnCancelCommConfig;
-extern Fl_Return_Button *btnOkXcvrDialog;
+
+extern Fl_Button *btnCloseCommConfig;
+extern Fl_Button *btnOkXcvrDialog;
+extern Fl_Button *btnOkSepSerial;
+extern Fl_Button *btnOkAuxSerial;
+
 extern Fl_Counter *inp_tcpip_ping_delay;
 extern Fl_Counter *cntRetryAfter;
 extern Fl_Counter *cntDropsAllowed;
@@ -394,4 +438,24 @@ extern Fl_Button *sel_50;
 extern Fl_Button *sel_200;
 extern Fl_Output *pwr_scale_description;
 
+extern Fl_Group *tabRestore;
+extern Fl_Check_Button *btnRestoreFrequency;
+extern Fl_Check_Button *btnRestoreMode;
+extern Fl_Check_Button *btnRestoreBandwidth;
+extern Fl_Check_Button *btnRestoreVolume;
+extern Fl_Check_Button *btnRestoreMicGain;
+extern Fl_Check_Button *btnRestoreRfGain;
+extern Fl_Check_Button *btnRestorePowerControl;
+extern Fl_Check_Button *btnRestoreIFshift;
+extern Fl_Check_Button *btnRestoreNotch;
+extern Fl_Check_Button *btnRestoreAutoNotch;
+extern Fl_Check_Button *btnRestoreSquelch;
+extern Fl_Check_Button *btnRestoreSplit;
+extern Fl_Check_Button *btnRestorePreAtt;
+extern Fl_Check_Button *btnRestoreNoise;
+extern Fl_Check_Button *btnRestoreNR;
+extern Fl_Check_Button *btnRestoreCompOnOff;
+extern Fl_Check_Button *btnRestoreCompLevel;
+extern Fl_Check_Button *btnUseRigData;
+
 #endif
