@@ -29,6 +29,8 @@
 
 using namespace std;
 
+#define FPLEN 20 // used in tt550 power sample
+
 struct status {
 	int		mainX;
 	int		mainY;
@@ -53,6 +55,7 @@ struct status {
 	int		byte_interval;
 
 	string	aux_serial_port;
+	bool	aux_SCU_17;
 	bool	aux_rts;
 	bool	aux_dtr;
 
@@ -61,6 +64,7 @@ struct status {
 	bool	sep_dtrptt;
 	bool	sep_rtsplus;
 	bool	sep_dtrplus;
+	bool	sep_SCU_17;
 	int		CIV;
 	bool	USBaudio;
 
@@ -83,7 +87,10 @@ struct status {
 	int		poll_split;
 	int		poll_noise;
 	int		poll_nr;
-	int     	poll_vfoAorB;
+	int 	poll_vfoAorB;
+	int		poll_meters;
+	int		poll_ops;
+	int		poll_compression;
 	int		poll_all;
 
 	int		iBW_A;
@@ -93,7 +100,6 @@ struct status {
 	int		imode_B;
 	int		freq_B;
 	bool	use_rig_data;
-	bool	restore_rig_data;
 
 	bool	spkr_on;
 	int		volume;
@@ -119,7 +125,7 @@ struct status {
 	bool	spot_onoff;
 	int		cw_spot_tone;
 	bool	enable_keyer;
-	bool	break_in;
+	int		break_in;
 	double	cw_qsk;
 	double	cw_delay;
 	bool	vox_onoff;
@@ -151,6 +157,24 @@ struct status {
 
 	bool	ft950_rg_reverse;
 
+	bool	restore_frequency;
+	bool	restore_mode;
+	bool	restore_bandwidth;
+	bool	restore_volume;
+	bool	restore_mic_gain;
+	bool	restore_rf_gain;
+	bool	restore_power_control;
+	bool	restore_if_shift;
+	bool	restore_notch;
+	bool	restore_auto_notch;
+	bool	restore_noise;
+	bool	restore_squelch;
+	bool	restore_split;
+	bool	restore_pre_att;
+	bool	restore_nr;
+	bool	restore_comp_on_off;
+	bool	restore_comp_level;
+
 //============= transceiver specific prameters
 //tt550 controls
 	int		tt550_line_out;
@@ -194,6 +218,11 @@ struct status {
 	int		tt550_F2_func;
 	int		tt550_F3_func;
 
+	int		tt550_Nsamples;
+	bool	tt550_at11_inline;
+	bool	tt550_at11_hiZ;
+
+// =========================
 //and others
 	double	vfo_adj;
 	int		bfo_freq;
@@ -202,8 +231,31 @@ struct status {
 	int		bpf_center;
 	bool	use_bpf_center;
 
-// =========================
+// IC706MKIIG filters
+	bool	use706filters;
+	string	ssb_cw_wide;		//FL-103
+	string	ssb_cw_normal;		//FL-272
+	string	ssb_cw_narrow;		//FL-232
 
+// =========================
+// User command buttons
+   string	label1;
+   string	command1;
+   string	label2;
+   string	command2;
+   string	label3;
+   string	command3;
+   string	label4;
+   string	command4;
+   string	label5;
+   string	command5;
+   string	label6;
+   string	command6;
+   string	label7;
+   string	command7;
+   string	label8;
+   string	command8;
+// =========================
 	int		bg_red;
 	int		bg_green;
 	int		bg_blue;
@@ -258,8 +310,8 @@ struct status {
 
 	string	ui_scheme;
 
-	string	server_port;
-	string	server_addr;
+//	string	server_port;
+//	string	server_addr;
 
 	string	tcpip_port;
 	string	tcpip_addr;
@@ -273,7 +325,7 @@ struct status {
 
 	bool	external_tuner;
 
-	bool	fldigi_is_server;
+//	bool	fldigi_is_server;
 
 	void saveLastState();
 	void loadLastState();
