@@ -23,6 +23,7 @@
 #include <stdlib.h>
 #include <iostream>
 #include <fstream>
+#include <sstream>
 #include <cstring>
 #include <ctime>
 #include <sys/types.h>
@@ -71,10 +72,12 @@
 #include "util.h"
 #include "gettext.h"
 #include "xml_server.h"
-#include "xml_io.h"
-
+//#include "xml_io.h"
+#include "serial.h"
 #include "ui.h"
 
+#include "tod_clock.h"
+
 #include "flrig_icon.cxx"
 
 int parse_args(int argc, char **argv, int& idx);
@@ -87,6 +90,10 @@ string TempDir;
 string defFileName;
 string title;
 
+#ifdef IC_DEBUG
+string ICDEBUGfname;
+#endif
+
 pthread_t *serial_thread = 0;
 pthread_t *digi_thread = 0;
 
@@ -100,6 +107,8 @@ bool RIG_DEBUG = false;
 bool XML_DEBUG = false;
 bool EXPAND_CONTROLS = false;
 
+int xmlport = 12345;
+
 //----------------------------------------------------------------------
 void about()
 {
@@ -291,6 +300,27 @@ void startup(void*)
 			if (EXPAND_CONTROLS && selrig->has_extras)
 				show_controls();
 	}
+
+}
+
+void rotate_log(std::string filename)
+{
+	const int n = 5; // rename existing log files to keep up to 5 old versions
+	ostringstream oldfn, newfn;
+	ostringstream::streampos p;
+
+	oldfn << filename << '.';
+	newfn << filename << '.';
+	p = oldfn.tellp();
+
+	for (int i = n - 1; i > 0; i--) {
+		oldfn.seekp(p);
+		newfn.seekp(p);
+		oldfn << i;
+		newfn << i + 1;
+		rename(oldfn.str().c_str(), newfn.str().c_str());
+	}
+	rename(filename.c_str(), oldfn.str().c_str());
 }
 
 int main (int argc, char *argv[])
@@ -345,14 +375,29 @@ int main (int argc, char *argv[])
 #endif
 	checkdirectories();
 
+#if SERIAL_DEBUG
+extern FILE *serlog;
+	std::string serlogname = RigHomeDir;
+	serlogname.append("serlog.txt");
+	serlog = fopen(serlogname.c_str(), "w");
+#endif
+
+	RigSerial = new Cserial;
+	SepSerial = new Cserial;
+	AuxSerial = new Cserial;
+
 	try {
-		debug::start(string(RigHomeDir).append("debug_log.txt").c_str());
+		std::string fname = RigHomeDir;
+		fname.append("debug_log.txt");
+		rotate_log(fname);
+		debug::start(fname.c_str());
 		time_t t = time(NULL);
-// for testing purposes only
-//		debug::level = debug::INFO_LEVEL;
-//		RIG_DEBUG = true;
-//
 		LOG(debug::INFO_LEVEL, debug::LOG_OTHER, _("%s log started on %s"), PACKAGE_STRING, ctime(&t));
+#ifdef IC_DEBUG
+		ICDEBUGfname = RigHomeDir;
+		ICDEBUGfname.append("civ.txt");
+		rotate_log(ICDEBUGfname);
+#endif
 	}
 	catch (const char* error) {
 		cerr << error << '\n';
@@ -394,15 +439,18 @@ int main (int argc, char *argv[])
 		exit(EXIT_FAILURE);
 	}
 
-	if (progStatus.fldigi_is_server) {
-		open_rig_xmlrpc();
-		digi_thread = new pthread_t;      
-		if (pthread_create(digi_thread, NULL, digi_loop, NULL)) {
-			perror("pthread_create");
-			exit(EXIT_FAILURE);
-		}
-	} else
-		start_server();
+	TOD_init();
+
+//	if (progStatus.fldigi_is_server) {
+//		open_rig_xmlrpc();
+//		digi_thread = new pthread_t;      
+//		if (pthread_create(digi_thread, NULL, digi_loop, NULL)) {
+//			perror("pthread_create");
+//			exit(EXIT_FAILURE);
+//		}
+//	} else
+
+	start_server(xmlport);
 
 	createXcvrDialog();
 
@@ -416,7 +464,11 @@ int main (int argc, char *argv[])
 		case small_ui :
 			mainwindow->resize(
 				progStatus.mainX, progStatus.mainY, 
-				mainwindow->w(), btnPTT->y() + btnPTT->h() + 2);
+				mainwindow->w(), 150);//mainwindow->h());
+				grpInitializing->size(mainwindow->w(), mainwindow->h() - grpInitializing->y());
+				grpInitializing->redraw();
+				progress->position(progress->x(), grpInitializing->y() + grpInitializing->h()/2);
+				progress->redraw();
 			break;
 		case wide_ui :
 			mainwindow->resize(
@@ -451,7 +503,7 @@ int main (int argc, char *argv[])
 		btn_show_controls->redraw_label();
 	}
 
-	Fl::add_timeout(0, startup);//0.50, startup);
+	Fl::add_timeout(0.5, startup);
 
 	return Fl::run();
 
