@@ -533,8 +533,22 @@ void RIG_FT950::set_PTT_control(int val)
 	cmd = val ? "TX1;" : "TX0;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET PTT", cmd, replystr);
+	ptt_ = val;
 }
 
+int RIG_FT950::get_PTT()
+{
+	cmd = "TX;";
+	rsp = "TX";
+	waitN(4, 100, "get PTT", ASC);
+
+	size_t p = replystr.rfind(rsp);
+	if (p == string::npos) return ptt_;
+	ptt_ =  (replystr[p+2] != '0' ? 1 : 0);
+	return ptt_;
+}
+
+
 // internal or external tune mode
 void RIG_FT950::tune_rig()
 {
@@ -598,19 +612,27 @@ void RIG_FT950::tune_rig()
 	}
 }
 
+int  RIG_FT950::next_attenuator()
+{
+	switch (atten_level) {
+		case 0: return 1;
+		case 1: return 2;
+		case 2: return 3;
+		case 3: return 0;
+	}
+	return 0;
+}
+
 void RIG_FT950::set_attenuator(int val)
 {
-	if (atten_level == 0) {
-		atten_level = 1;
+	atten_level = val;
+	if (atten_level == 1) {
 		atten_label("6 dB", true);
-	} else if (atten_level == 1) {
-		atten_level = 2;
-		atten_label("12 dB", true);
 	} else if (atten_level == 2) {
-		atten_level = 3;
-		atten_label("18 dB", true);
+		atten_label("12 dB", true);
 	} else if (atten_level == 3) {
-		atten_level = 0;
+		atten_label("18 dB", true);
+	} else if (atten_level == 0) {
 		atten_label("Att", false);
 	}
 	cmd = "RA00;";
@@ -642,17 +664,25 @@ int RIG_FT950::get_attenuator()
 	return atten_level;
 }
 
+int RIG_FT950::next_preamp()
+{
+	switch (preamp_level) {
+		case 0: return 1;
+		case 1: return 2;
+		case 2: return 0;
+	}
+	return 0;
+}
+
 void RIG_FT950::set_preamp(int val)
 {
+	preamp_level = val;
 	cmd = "PA00;";
-	if (preamp_level == 0) {
-		preamp_level = 1;
+	if (preamp_level == 1) {
 		preamp_label("Amp 1", true);
-	} else if (preamp_level == 1) {
-		preamp_level = 2;
-		preamp_label("Amp 2", true);
 	} else if (preamp_level == 2) {
-		preamp_level = 0;
+		preamp_label("Amp 2", true);
+	} else if (preamp_level == 0) {
 		preamp_label("IPO", false);
 	}
 	cmd[3] = '0' + preamp_level;
@@ -872,7 +902,7 @@ int RIG_FT950::get_bwA()
 	if (p + 5 >= replystr.length()) return bwA;
 
 	replystr[p+5] = 0;
-	int bw_idx = fm_decimal(&replystr[p+3],2);
+	int bw_idx = fm_decimal(replystr.substr(p+3),2);
 	const int *idx = bw_vals_;
 	int i = 0;
 	while (*idx != WVALS_LIMIT) {
@@ -939,7 +969,7 @@ int RIG_FT950::get_bwB()
 	if (p + 5 >= replystr.length()) return bwB;
 
 	replystr[p+5] = 0;
-	int bw_idx = fm_decimal(&replystr[p+3],2);
+	int bw_idx = fm_decimal(replystr.substr(p+3),2);
 	const int *idx = bw_vals_;
 	int i = 0;
 	while (*idx != WVALS_LIMIT) {
@@ -1037,7 +1067,7 @@ bool  RIG_FT950::get_notch(int &val)
 		if (p == string::npos)
 			val = 10;
 		else
-			val = fm_decimal(&replystr[p+4],3) * 10;
+			val = fm_decimal(replystr.substr(p+4),3) * 10;
 	}
 	return ison;
 }
@@ -1245,7 +1275,7 @@ void RIG_FT950::enable_keyer()
 
 bool RIG_FT950::set_cw_spot()
 {
-	if (vfo.imode == mCW || vfo.imode == mCW_R) {
+	if (vfo->imode == mCW || vfo->imode == mCW_R) {
 		cmd = "CS0;";
 		if (progStatus.spot_onoff) cmd[2] = '1';
 		sendCommand(cmd);
@@ -1383,15 +1413,15 @@ void RIG_FT950::set_xcvr_auto_off()
 	sendCommand(cmd);
 }
 
-void RIG_FT950::set_compression()
+void RIG_FT950::set_compression(int on, int val)
 {
-	if (progStatus.compON) {
-		if (progStatus.compression == 0) {
+	if (on) {
+		if (val == 0) {
 			cmd.assign("PR2;");	// mic eq on
 			sendCommand(cmd);
 			showresp(WARN, ASC, "set Comp EQ on", cmd, replystr);
 		} else {
-			cmd.assign("PR1;PL").append(to_decimal(progStatus.compression, 3)).append(";");
+			cmd.assign("PR1;PL").append(to_decimal(val, 3)).append(";");
 			sendCommand(cmd);
 			showresp(WARN, ASC, "set Comp on", cmd, replystr);
 		}
@@ -1406,7 +1436,7 @@ void RIG_FT950::set_compression()
 // Audio Peak Filter, like set_cw_spot
 bool RIG_FT950::set_cw_APF()
 {
-	if (vfo.imode == mCW || vfo.imode == mCW_R) {
+	if (vfo->imode == mCW || vfo->imode == mCW_R) {
 		cmd = "CO0000;";
 		if (progStatus.apf_onoff) cmd[5] = '2';
 		sendCommand(cmd);
