@@ -170,7 +170,7 @@ void RIG_IC7000::initialize()
 	cmd += '\x92';
 	cmd += '\x00';
 	cmd.append(post);
-	if (!waitFB("CI-V") && RigSerial.IsOpen()) {
+	if (!waitFB("CI-V") && RigSerial->IsOpen()) {
 		flrig_abort = true;
 		return;
 	}
@@ -178,7 +178,7 @@ void RIG_IC7000::initialize()
 	cmd.append("\x16\x51");
 	cmd += '\x00';
 	cmd.append(post);
-	if (!waitFB("NF2 OFF") && RigSerial.IsOpen()) flrig_abort = true;
+	if (!waitFB("NF2 OFF") && RigSerial->IsOpen()) flrig_abort = true;
 }
 
 void RIG_IC7000::selectA()
@@ -187,7 +187,7 @@ void RIG_IC7000::selectA()
 	cmd += '\x07';
 	cmd += '\x00';
 	cmd.append(post);
-	if (!waitFB("sel A") && RigSerial.IsOpen()) flrig_abort = true;
+	if (!waitFB("sel A") && RigSerial->IsOpen()) flrig_abort = true;
 }
 
 void RIG_IC7000::selectB()
@@ -196,7 +196,7 @@ void RIG_IC7000::selectB()
 	cmd += '\x07';
 	cmd += '\x01';
 	cmd.append(post);
-	if (!waitFB("sel B") && RigSerial.IsOpen()) flrig_abort = true;
+	if (!waitFB("sel B") && RigSerial->IsOpen()) flrig_abort = true;
 }
 
 long RIG_IC7000::get_vfoA ()
@@ -209,8 +209,8 @@ long RIG_IC7000::get_vfoA ()
 	if (waitFOR(11, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
-			A.freq = fm_bcd_be(&replystr[p+5], 10);
-	} else if (RigSerial.IsOpen())
+			A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+	} else if (RigSerial->IsOpen())
 		flrig_abort = true;
 	return A.freq;
 }
@@ -235,8 +235,8 @@ long RIG_IC7000::get_vfoB ()
 	if (waitFOR(11, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
-			B.freq = fm_bcd_be(&replystr[p+5], 10);
-	} else if (RigSerial.IsOpen())
+			B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+	} else if (RigSerial->IsOpen())
 		flrig_abort = true;
 	return B.freq;
 }
@@ -251,15 +251,6 @@ void RIG_IC7000::set_vfoB (long freq)
 	waitFB("set vfo B");
 }
 
-void RIG_IC7000::swapvfos()
-{
-	cmd = pre_to;
-	cmd += '\x07';
-	cmd += '\xB0';
-	cmd.append( post );
-	waitFB("swap VFO A/B");
-}
-
 void RIG_IC7000::set_modeA(int val)
 {
 	A.imode = val;
@@ -290,7 +281,7 @@ int RIG_IC7000::get_modeA()
 			if (md > 6) md--;
 			A.imode = md;
 		}
-	} else if (RigSerial.IsOpen())
+	} else if (RigSerial->IsOpen())
 		flrig_abort = true;
 	return A.imode;
 }
@@ -325,7 +316,7 @@ int RIG_IC7000::get_modeB()
 			if (md > 6) md--;
 			B.imode = md;
 		}
-	} else if (RigSerial.IsOpen())
+	} else if (RigSerial->IsOpen())
 		flrig_abort = true;
 	return B.imode;
 }
@@ -341,8 +332,8 @@ int  RIG_IC7000::get_bwA()
 	if (waitFOR(8, "get bw A")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
-			A.iBW = (fm_bcd(&replystr[p+6],2));
-	} else if (RigSerial.IsOpen())
+			A.iBW = (fm_bcd(replystr.substr(p+6),2));
+	} else if (RigSerial->IsOpen())
 		flrig_abort = true;
 	return A.iBW;
 }
@@ -358,8 +349,8 @@ int  RIG_IC7000::get_bwB()
 	if (waitFOR(8, "get bw B")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
-			B.iBW = (fm_bcd(&replystr[p+6],2));
-	} else if (RigSerial.IsOpen())
+			B.iBW = (fm_bcd(replystr.substr(p+6),2));
+	} else if (RigSerial->IsOpen())
 		flrig_abort = true;
 	return B.iBW;
 }
@@ -503,30 +494,30 @@ int RIG_IC7000::get_auto_notch()
 
 void RIG_IC7000::set_split(bool val)
 {
+	split = val;
 	cmd = pre_to;
 	cmd += 0x0F;
 	cmd += val ? 0x01 : 0x00;
 	cmd.append(post);
-	waitFB("set split");
+	waitFB(val ? "set split ON" : "set split OFF");
 }
 
 int  RIG_IC7000::get_split()
 {
-	LOG_WARN("%s", "get split - not implemented");
-	return progStatus.split;
-/*
-	cmd = pre_to;
-	cmd += 0x0F;
-	cmd.append(post);
-	string resp = pre_fm;
-	resp += 0x0F;
-	if (waitFOR(8, "get split")) {
-		size_t p = replystr.rfind(resp);
+	int read_split = 0;
+	cmd.assign(pre_to);
+	cmd.append("\x0F");
+	cmd.append( post );
+	if (waitFOR(7, "get split")) {
+		string resp = pre_fm;
+		resp.append("\x0F");
+		size_t p = replystr.find(resp);
 		if (p != string::npos)
-			return (replystr[p+6] ? 1 : 0);
+			read_split = replystr[p+5];
+		if (read_split != 0xFA) // fail byte
+			split = read_split;
 	}
-	return 0;
-*/
+	return split;
 }
 
 // Volume control val 0 ... 100
@@ -551,7 +542,7 @@ int RIG_IC7000::get_volume_control()
 	if (waitFOR(9, "get vol")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
-			return (int)ceil(fm_bcd(&replystr[p + 6],3) * 100 / 255);
+			return (int)ceil(fm_bcd(replystr.substr(p + 6),3) * 100 / 255);
 	}
 	return progStatus.volume;
 }
@@ -581,7 +572,7 @@ int RIG_IC7000::get_rf_gain()
 	if (waitFOR(9, "get RF")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
-			return (int)ceil(fm_bcd(&replystr[p + 6],3) * 100 / 255);
+			return (int)ceil(fm_bcd(replystr.substr(p + 6),3) * 100 / 255);
 	}
 	return progStatus.rfgain;
 }
@@ -607,7 +598,7 @@ int  RIG_IC7000::get_squelch()
 	if (waitFOR(9, "get sql")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
-			return (int)ceil(fm_bcd(&replystr[p+6], 3) * 100 / 255);
+			return (int)ceil(fm_bcd(replystr.substr(p+6), 3) * 100 / 255);
 	}
 	return progStatus.squelch;
 }
@@ -631,7 +622,7 @@ int RIG_IC7000::get_power_control()
 	if (waitFOR(9, "get power")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
-			return (int)ceil(fm_bcd(&replystr[p + 6],3) * 100 / 255);
+			return (int)ceil(fm_bcd(replystr.substr(p + 6),3) * 100 / 255);
 	}
 	return progStatus.power_level;
 }
@@ -648,7 +639,7 @@ int RIG_IC7000::get_smeter()
 	if (waitFOR(9, "get smeter")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
-			mtr = fm_bcd(&replystr[p+6], 3);
+			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.55);
 			if (mtr > 100) mtr = 100;
 		}
@@ -668,7 +659,7 @@ int RIG_IC7000::get_power_out()
 	if (waitFOR(9, "get pout")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
-			mtr = fm_bcd(&replystr[p+6], 3);
+			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.55);
 			if (mtr > 100) mtr = 100;
 		}
@@ -688,7 +679,7 @@ int RIG_IC7000::get_alc()
 	if (waitFOR(9, "get alc")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
-			mtr = fm_bcd(&replystr[p+6], 3);
+			mtr = fm_bcd(replystr.substr(p+6), 3);
 			mtr = (int)ceil(mtr /2.55);
 			if (mtr > 100) mtr = 100;
 		}
@@ -707,7 +698,7 @@ int RIG_IC7000::get_mic_gain()
 	if (waitFOR(9, "get mic")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
-			return (int)ceil(fm_bcd(&replystr[p+6],3) / 2.55);
+			return (int)ceil(fm_bcd(replystr.substr(p+6),3) / 2.55);
 	}
 	return 0;
 }
@@ -771,7 +762,7 @@ bool RIG_IC7000::get_notch(int &val)
 		if (waitFOR(9, "notch val")) {
 			size_t p = replystr.rfind(resp);
 			if (p != string::npos)
-				val = (int)ceil(fm_bcd(&replystr[p+6],3) * 3000.0 / 255.0);
+				val = (int)ceil(fm_bcd(replystr.substr(p+6),3) * 3000.0 / 255.0);
 		}
 	}
 	return on;
@@ -855,14 +846,14 @@ int RIG_IC7000::get_noise_reduction_val()
 	if (waitFOR(9, "get NR val")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
-			return (int)ceil(fm_bcd(&replystr[p+6],3) / 2.55);
+			return (int)ceil(fm_bcd(replystr.substr(p+6),3) / 2.55);
 	}
 	return 0;
 }
 
-void RIG_IC7000::set_compression()
+void RIG_IC7000::set_compression(int on, int val)
 {
-	if (progStatus.compON) {
+	if (on) {
 		cmd = pre_to;
 		cmd.append("\x16\x44");
 		cmd += '\x01';
@@ -870,7 +861,7 @@ void RIG_IC7000::set_compression()
 		waitFB("set Comp ON");
 
 		cmd.assign(pre_to).append("\x14\x0E");
-		cmd.append(to_bcd(progStatus.compression * 255 / 10, 3));	// 0 - 10
+		cmd.append(to_bcd(val * 255 / 10, 3));	// 0 - 10
 		cmd.append( post );
 		waitFB("set comp level");
 
@@ -882,3 +873,30 @@ void RIG_IC7000::set_compression()
 	}
 }
 
+// Tranceiver PTT on/off
+void RIG_IC7000::set_PTT_control(int val)
+{
+	cmd = pre_to;
+	cmd += '\x1c';
+	cmd += '\x00';
+	cmd += (unsigned char) val;
+	cmd.append( post );
+	waitFB("set ptt");
+	ptt_ = val;
+}
+
+int RIG_IC7000::get_PTT()
+{
+	cmd = pre_to;
+	cmd += '\x1c'; cmd += '\x00';
+	string resp = pre_fm;
+	resp += '\x1c'; resp += '\x00';
+	cmd.append(post);
+	if (waitFOR(8, "get PTT")) {
+		size_t p = replystr.rfind(resp);
+		if (p != string::npos)
+			ptt_ = replystr[p + 6];
+	}
+	return ptt_;
+}
+
