@@ -223,7 +223,7 @@ long RIG_IC756PRO::get_vfoA ()
 	if (waitFOR(11, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
-			A.freq = fm_bcd_be(&replystr[p+5], 10);
+			A.freq = fm_bcd_be(replystr.substr(p+5), 10);
 	}
 	return A.freq;
 }
@@ -249,7 +249,7 @@ long RIG_IC756PRO::get_vfoB ()
 	if (waitFOR(11, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
-			B.freq = fm_bcd_be(&replystr[p+5], 10);
+			B.freq = fm_bcd_be(replystr.substr(p+5), 10);
 	}
 	return B.freq;
 }
@@ -275,7 +275,7 @@ int RIG_IC756PRO::get_smeter()
 	if (waitFOR(9, "get smeter")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
-			return (int)ceil(fm_bcd(&replystr[p+6], 3) / 2.55);
+			return (int)ceil(fm_bcd(replystr.substr(p+6), 3) / 2.55);
 	}
 	return 0;
 }
@@ -284,7 +284,7 @@ int RIG_IC756PRO::get_smeter()
 
 void RIG_IC756PRO::set_volume_control(int val)
 {
-	ICvol = (int)(val);
+	ICvol = (int)(val * 255 / 100);
 	cmd = pre_to;
 	cmd.append("\x14\x01");
 	cmd.append(to_bcd(ICvol, 3));
@@ -303,14 +303,14 @@ int RIG_IC756PRO::get_volume_control()
 	if (waitFOR(9, "get vol")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos)
-			return ((int)(fm_bcd(&replystr[p+6],3)));
+			return ((int)ceil(fm_bcd(replystr.substr(p+6),3) * 100 / 255));
 	}
-	return 0;
+	return progStatus.volume;
 }
 
 void RIG_IC756PRO::get_vol_min_max_step(int &min, int &max, int &step)
 {
-	min = 0; max = 255; step = 1;
+	min = 0; max = 100; step = 1;
 }
 
 // Tranceiver PTT on/off
@@ -321,7 +321,23 @@ void RIG_IC756PRO::set_PTT_control(int val)
 	cmd += '\x00';
 	cmd += (unsigned char) val;
 	cmd.append( post );
-	waitFB("set PTT");
+	waitFB("set ptt");
+	ptt_ = val;
+}
+
+int RIG_IC756PRO::get_PTT()
+{
+	cmd = pre_to;
+	cmd += '\x1c'; cmd += '\x00';
+	string resp = pre_fm;
+	resp += '\x1c'; resp += '\x00';
+	cmd.append(post);
+	if (waitFOR(8, "get PTT")) {
+		size_t p = replystr.rfind(resp);
+		if (p != string::npos)
+			ptt_ = replystr[p + 6];
+	}
+	return ptt_;
 }
 
 // changed noise blanker to noise reduction
@@ -374,8 +390,15 @@ void RIG_IC756PRO::get_mic_gain_min_max_step(int &min, int &max, int &step)
 
 void RIG_IC756PRO::set_if_shift(int val)
 {
-	int shift = (int)((val + 50) * 2.56 );
-	if (shift == 256) shift = 255;
+	int shift;
+	sh_ = val;
+	if (val == 0) sh_on_ = false;
+	else sh_on_ = true;
+
+	shift = 128 + val * 128 / 50;
+	if (shift < 0) shift = 0;
+	if (shift > 255) shift = 255;
+
 	cmd = pre_to;
 	cmd.append("\x14\x07");
 	cmd.append(to_bcd(shift, 3));
@@ -393,7 +416,7 @@ void RIG_IC756PRO::get_if_min_max_step(int &min, int &max, int &step)
 {
 	min = -50;
 	max = +50;
-	step = 2;
+	step = 1;
 }
 
 int IC756PROsql = 0;
@@ -540,23 +563,31 @@ int  RIG_IC756PRO::get_auto_notch()
 	return progStatus.auto_notch;
 }
 
+int  RIG_IC756PRO::next_attenuator()
+{
+	switch(atten_level) {
+		case 0: return 1;
+		case 1: return 2;
+		case 2: return 3;
+		case 3: return 0;
+	}
+	return 0;
+}
+
 void RIG_IC756PRO::set_attenuator(int val)
 {
+	atten_level = val;
 	int cmdval = 0;
-	if (atten_level == 0) {
-		atten_level = 1;
+	if (atten_level == 1) {
 		atten_label("6 dB", true);
 		cmdval = 0x06;
-	} else if (atten_level == 1) {
-		atten_level = 2;
+	} else if (atten_level == 2) {
 		atten_label("12 dB", true);
 		cmdval = 0x12;
-	} else if (atten_level == 2) {
-		atten_level = 3;
+	} else if (atten_level == 3) {
 		atten_label("18 dB", true);
 		cmdval = 0x18;
-	} else if (atten_level == 3) {
-		atten_level = 0;
+	} else if (atten_level == 0) {
 		atten_label("Att", false);
 		cmdval = 0x00;
 	}
@@ -596,18 +627,26 @@ int RIG_IC756PRO::get_attenuator()
 	return atten_level;
 }
 
+int  RIG_IC756PRO::next_preamp()
+{
+	switch (preamp_level) {
+		case 0: return 1;
+		case 1: return 2;
+		case 2: return 0;
+	}
+	return 0;
+}
+
 void RIG_IC756PRO::set_preamp(int val)
 {
-	if (preamp_level == 0) {
-		preamp_level = 1;
+	preamp_level = val;
+	if (preamp_level == 1)
 		preamp_label("Pre 1", true);
-	} else if (preamp_level == 1) {
-		preamp_level = 2;
+	else if (preamp_level == 2)
 		preamp_label("Pre 2", true);
-	} else if (preamp_level == 2) {
-		preamp_level = 0;
+	else if (preamp_level == 0)
 		preamp_label("Pre", false);
-	}
+
 	cmd = pre_to;
 	cmd += '\x16';
 	cmd += '\x02';
