@@ -90,6 +90,9 @@ static int TS480SAT_FSK_bw_vals[] = { 1,2,3,4,WVALS_LIMIT};
 static const char *TS480SAT_FSKbw[] = {
 "FW0250;", "FW0500;", "FW1000;", "FW1500;" };
 
+static int agcval = 1;
+static bool fm_mode = false;
+
 static GUI rig_widgets[]= {
 	{ (Fl_Widget *)btnVol,        2, 125,  50 },
 	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },
@@ -113,11 +116,6 @@ void RIG_TS480SAT::initialize()
 	rig_widgets[6].W = sldrMICGAIN;
 	rig_widgets[7].W = sldrPOWER;
 
-	if (progStatus.UIsize == small_ui) has_extras = false;
-	progStatus.rfgain = 100;
-	progStatus.volume = 25;
-	progStatus.power_level = 20;
-	progStatus.mic_gain = 25;
 	check_menu_45();
 };
 
@@ -139,8 +137,8 @@ RIG_TS480SAT::RIG_TS480SAT() {
 
 	widgets = rig_widgets;
 
-	comm_baudrate = BR4800;
-	stopbits = 2;
+	comm_baudrate = BR57600;
+	stopbits = 1;
 	comm_retries = 2;
 	comm_wait = 5;
 	comm_timeout = 50;
@@ -156,23 +154,26 @@ RIG_TS480SAT::RIG_TS480SAT() {
 
 	can_change_alt_vfo = true;
 
-	has_noise_control = false;
-	has_tune_control = false;
-	has_notch_control = false;
-
 	has_extras = true;
+
+	has_noise_reduction =
+	has_noise_reduction_control =
+	has_auto_notch =
+	has_noise_control =
+	has_sql_control =
+
 	has_split = true;
 	has_split_AB = true;
 	has_data_port = true;
 	has_micgain_control = true;
 	has_ifshift_control = true;
 	has_rf_control = true;
+	has_agc_control = true;
 	has_swr_control = true;
 	has_alc_control = true;
 	has_power_out = true;
 	has_dsp_controls = true;
 	has_smeter = true;
-	has_swr_control = true;
 	has_attenuator_control = true;
 	has_preamp_control = true;
 	has_mode_control = true;
@@ -185,6 +186,9 @@ RIG_TS480SAT::RIG_TS480SAT() {
 	precision = 1;
 	ndigits = 8;
 
+	_noise_reduction_level = 0;
+	_nrval1 = 2;
+	_nrval2 = 4;
 }
 
 const char * RIG_TS480SAT::get_bwname_(int n, int md) 
@@ -424,17 +428,6 @@ int  RIG_TS480SAT::get_alc(void)
 	return alc;
 }
 
-// Tranceiver PTT on/off
-void RIG_TS480SAT::set_PTT_control(int val)
-{
-	if (val) {
-		if (progStatus.data_port) cmd = "TX1;"; // DTS transmission using ANI input
-		else cmd = "TX0;"; // mic input
-	} else cmd = "RX;";
-	sendCommand(cmd);
-	showresp(WARN, ASC, "set PTT", cmd, "");
-}
-
 int RIG_TS480SAT::set_widths(int val)
 {
 	int bw;
@@ -518,6 +511,8 @@ const char **RIG_TS480SAT::hitable(int m)
 
 void RIG_TS480SAT::set_modeA(int val)
 {
+	if (val == 3) fm_mode = true;
+	else fm_mode = false;
 	A.imode = val;
 	cmd = "MD";
 	cmd += TS480SAT_mode_chr[val];
@@ -540,11 +535,15 @@ int RIG_TS480SAT::get_modeA()
 		A.imode = md;
 		A.iBW = set_widths(A.imode);
 	}
+	if (A.imode == 3) fm_mode = true;
+	else fm_mode = false;
 	return A.imode;
 }
 
 void RIG_TS480SAT::set_modeB(int val)
 {
+	if (val == 3) fm_mode = true;
+	else fm_mode = false;
 	B.imode = val;
 	cmd = "MD";
 	cmd += TS480SAT_mode_chr[val];
@@ -567,6 +566,8 @@ int RIG_TS480SAT::get_modeB()
 		B.imode = md;
 		B.iBW = set_widths(B.imode);
 	}
+	if (B.imode == 3) fm_mode = true;
+	else fm_mode = false;
 	return B.imode;
 }
 
@@ -620,13 +621,13 @@ int RIG_TS480SAT::get_bwA()
 		if (wait_char(';', 5, 100, "get SL", ASC) == 5) {
 			p = replystr.rfind("SL");
 			if (p != string::npos)
-				lo = fm_decimal(&replystr[2], 2);
+				lo = fm_decimal(replystr.substr(p+2), 2);
 		}
 		cmd = "SH;";
 		if (wait_char(';', 5, 100, "get SH", ASC) == 5) {
 			p = replystr.rfind("SH");
 			if (p != string::npos)
-				hi = fm_decimal(&replystr[2], 2);
+				hi = fm_decimal(replystr.substr(p+2), 2);
 			A.iBW = ((hi << 8) | (lo & 0xFF)) | 0x8000;
 		}
 	} else if (A.imode == 2 || A.imode == 6) {
@@ -701,13 +702,13 @@ int RIG_TS480SAT::get_bwB()
 		if (wait_char(';', 5, 100, "get SL", ASC) == 5) {
 			p = replystr.rfind("SL");
 			if (p != string::npos)
-				lo = fm_decimal(&replystr[2], 2);
+				lo = fm_decimal(replystr.substr(p+2), 2);
 		}
 		cmd = "SH;";
 		if (wait_char(';', 5, 100, "get SH", ASC) == 5) {
 			p = replystr.rfind("SH");
 			if (p != string::npos)
-				hi = fm_decimal(&replystr[2], 2);
+				hi = fm_decimal(replystr.substr(p+2), 2);
 			B.iBW = ((hi << 8) | (lo & 0xFF)) | 0x8000;
 		}
 	} else if (B.imode == 2 || B.imode == 6) {
@@ -868,7 +869,7 @@ bool RIG_TS480SAT::get_if_shift(int &val)
 	if (wait_char(';', 8, 100, "get IF shift", ASC) == 8) {
 		size_t p = replystr.rfind("IS");
 		if (p != string::npos) {
-			val = fm_decimal(&replystr[p+3], 4);
+			val = fm_decimal(replystr.substr(p+3), 4);
 			if (replystr[p+2] == '-') val *= -1;
 			return (val != 0);
 		}
@@ -901,7 +902,7 @@ int  RIG_TS480SAT::get_mic_gain()
 
 	size_t p = replystr.rfind("MG");
 	if (p != string::npos)
-		val = fm_decimal(&replystr[p+2], 3);
+		val = fm_decimal(replystr.substr(p+2), 3);
 	return val;
 }
 
@@ -926,7 +927,7 @@ int  RIG_TS480SAT::get_rf_gain()
 
 	size_t p = replystr.rfind("RG");
 	if (p != string::npos)
-		val = fm_decimal(&replystr[p+2], 3);
+		val = fm_decimal(replystr.substr(p+2), 3);
 	return val;
 }
 
@@ -935,3 +936,233 @@ void RIG_TS480SAT::get_rf_min_max_step(int &min, int &max, int &step)
 	min = 0; max = 100; step = 1;
 }
 
+// Noise Reduction (TS2000.cxx) NR1 only works; no NR2 and don' no why
+void RIG_TS480SAT::set_noise_reduction(int val)
+{
+	if (val == -1) {
+		return;
+	}
+	_noise_reduction_level = val;
+	if (_noise_reduction_level == 0) {
+		nr_label("NR", false);
+	} else if (_noise_reduction_level == 1) {
+		nr_label("NR1", true);
+	} else if (_noise_reduction_level == 2) {
+		nr_label("NR2", true);
+	}
+	cmd.assign("NR");
+	cmd += '0' + _noise_reduction_level;
+	cmd += ';';
+	sendCommand (cmd);
+	showresp(WARN, ASC, "SET noise reduction", cmd, "");
+}
+
+int  RIG_TS480SAT::get_noise_reduction()
+{
+	cmd = rsp = "NR";
+	cmd.append(";");
+	if (wait_char(';', 4, 100, "GET noise reduction", ASC) == 4) {
+		size_t p = replystr.rfind(rsp);
+		if (p == string::npos) return _noise_reduction_level;
+		_noise_reduction_level = replystr[p+2] - '0';
+	}
+
+	if (_noise_reduction_level == 1) {
+		nr_label("NR1", true);
+	} else if (_noise_reduction_level == 2) {
+		nr_label("NR2", true);
+	} else {
+		nr_label("NR", false);
+	}
+
+	return _noise_reduction_level;
+}
+
+void RIG_TS480SAT::set_noise_reduction_val(int val)
+{
+	if (_noise_reduction_level == 0) return;
+	if (_noise_reduction_level == 1) _nrval1 = val;
+	else _nrval2 = val;
+
+	cmd.assign("RL").append(to_decimal(val, 2)).append(";");
+	sendCommand(cmd);
+	showresp(WARN, ASC, "SET_noise_reduction_val", cmd, "");
+}
+
+int  RIG_TS480SAT::get_noise_reduction_val()
+{
+	int nrval = 0;
+	if (_noise_reduction_level == 0) return 0;
+	int val = progStatus.noise_reduction_val;
+	cmd = rsp = "RL";
+	cmd.append(";");
+	if (wait_char(';', 5, 100, "GET noise reduction val", ASC) == 5) {
+		size_t p = replystr.rfind(rsp);
+		if (p == string::npos) {
+			nrval = (_noise_reduction_level == 1 ? _nrval1 : _nrval2);
+			return nrval;
+		}
+		val = atoi(&replystr[p+2]);
+	}
+
+	if (_noise_reduction_level == 1) _nrval1 = val;
+	else _nrval2 = val;
+
+	return val;
+}
+
+int  RIG_TS480SAT::get_agc()
+{
+	cmd = "GT;";
+	wait_char(';', 6, 100, "GET agc val", ASC);
+	size_t p = replystr.rfind("GT");
+	if (p == string::npos) return agcval;
+	if (replystr[4] == ' ') return 0;
+	agcval = replystr[4] - '0' + 1; // '0' == off, '1' = fast, '2' = slow
+	return agcval;
+}
+
+int RIG_TS480SAT::incr_agc()
+{
+	if (fm_mode) return 0;
+	agcval++;
+	if (agcval == 4) agcval = 1;
+	cmd.assign("GT00");
+	cmd += (agcval + '0' - 1);
+	cmd += ";";
+	sendCommand(cmd);
+	showresp(WARN, ASC, "SET agc", cmd, replystr);
+	return agcval;
+}
+
+
+static const char *agcstrs[] = {"FM", "AGC", "FST", "SLO"};
+const char *RIG_TS480SAT::agc_label()
+{
+	if (fm_mode) return agcstrs[0];
+	return agcstrs[agcval];
+}
+
+int  RIG_TS480SAT::agc_val()
+{
+	if (fm_mode) return 0;
+	return agcval;
+}
+
+// Auto Notch, beat canceller (TS2000.cxx) BC1 only, not BC2
+void RIG_TS480SAT::set_auto_notch(int v)
+{
+	cmd = v ? "BC1;" : "BC0;";
+	sendCommand(cmd);
+	showresp(WARN, ASC, "set auto notch", cmd, "");
+
+}
+
+int  RIG_TS480SAT::get_auto_notch()
+{
+	cmd = "BC;";
+	if (wait_char(';', 4, 100, "get auto notch", ASC) == 4) {
+		int anotch = 0;
+		size_t p = replystr.rfind("BC");
+		if (p != string::npos) {
+			anotch = (replystr[p+2] == '1');
+			return anotch;
+		}
+	}
+	return 0;
+}
+
+// Noise Blanker (TS2000.cxx)
+void RIG_TS480SAT::set_noise(bool b)
+{
+	if (b)
+		cmd = "NB1;";
+	else
+		cmd = "NB0;";
+	sendCommand(cmd);
+	showresp(WARN, ASC, "set NB", cmd, "");
+}
+
+int RIG_TS480SAT::get_noise()
+{
+	cmd = "NB;";
+	if (wait_char(';', 4, 100, "get Noise Blanker", ASC) == 4) {
+		size_t p = replystr.rfind("NB");
+		if (p == string::npos) return 0;
+		if (replystr[p+2] == '0') return 0;
+	}
+	return 1;
+}
+
+// Squelch (TS990.cxx)
+void RIG_TS480SAT::set_squelch(int val)
+{
+		cmd = "SQ0";
+		cmd.append(to_decimal(abs(val),3)).append(";");
+		sendCommand(cmd);
+		showresp(INFO, ASC, "set squelch", cmd, "");
+}
+
+int  RIG_TS480SAT::get_squelch()
+{
+	int val = 0;
+	cmd = "SQ0;";
+		if (wait_char(';', 7, 20, "get squelch", ASC) >= 7) {
+			size_t p = replystr.rfind("SQ0");
+			if (p == string::npos) return val;
+			replystr[p + 6] = 0;
+			val = atoi(&replystr[p + 3]);
+	}
+	return val;
+}
+
+void RIG_TS480SAT::get_squelch_min_max_step(int &min, int &max, int &step)
+{
+	min = 0; max = 255; step = 1;
+}
+
+// Tranceiver PTT on/off
+void RIG_TS480SAT::set_PTT_control(int val)
+{
+	if (val) {
+		if (progStatus.data_port) cmd = "TX1;"; // DTS transmission using ANI input
+		else cmd = "TX0;"; // mic input
+	} else cmd = "RX;";
+	sendCommand(cmd);
+	showresp(WARN, ASC, "set PTT", cmd, "");
+}
+
+/*
+========================================================================
+	frequency & mode data are contained in the IF; response
+		IFaaaaaaaaaaaXXXXXbbbbbcdXeefghjklmmX;
+		12345678901234567890123456789012345678
+		01234567890123456789012345678901234567 byte #
+		          1         2         3
+		                            ^ position 28
+		where:
+			aaaaaaaaaaa => decimal value of vfo frequency
+			bbbbb => rit/xit frequency
+			c => rit off/on
+			d => xit off/on
+			e => memory channel
+			f => tx/rx
+			g => mode
+			h => function
+			j => scan off/on
+			k => split off /on
+			l => tone off /on
+			m => tone number
+			X => unused characters
+		 
+========================================================================
+*/ 
+
+int RIG_TS480SAT::get_PTT()
+{
+	cmd = "IF;";
+	int ret = wait_char(';', 38, 100, "get VFO", ASC);
+	if (ret < 38) return ptt_;
+	ptt_ = (replybuff[28] == '1');
+	return ptt_;
+}
