@@ -85,6 +85,7 @@ rigbase::rigbase()
 	has_tune_control =
 	has_swr_control =
 	has_alc_control =
+	has_agc_control =
 	has_rf_control =
 	has_sql_control = 
 	has_data_port =
@@ -115,6 +116,7 @@ rigbase::rigbase()
 	has_ext_tuner =
 	has_smeter =
 	has_power_out =
+	has_line_out =
 	has_split =
 	has_split_AB =
 	has_a2b =
@@ -122,6 +124,8 @@ rigbase::rigbase()
 	has_get_info = 
 	has_getvfoAorB = false;
 
+	has_vfoAB = true;
+
 	data_type = BINARY;
 
 	A.freq = 14070000L;
@@ -156,6 +160,9 @@ rigbase::rigbase()
 	if_shift_max = 1500;
 	if_shift_step = 10;
 	if_shift_mid = 0;
+
+	atten_level = 0;
+	preamp_level = 0;
 }
 
 string rigbase::to_bcd_be(long freq, int len)
@@ -185,7 +192,7 @@ string rigbase::to_bcd(long freq, int len)
 	return bcd;
 }
 
-long rigbase::fm_bcd (char *bcd, int len)
+long rigbase::fm_bcd (string bcd, int len)
 {
 	int i;
 	long f = 0;
@@ -201,7 +208,7 @@ long rigbase::fm_bcd (char *bcd, int len)
 }
 
 
-long rigbase::fm_bcd_be(char *bcd, int len)
+long rigbase::fm_bcd_be(string bcd, int len)
 {
 	char temp;
 	int numchars = len/2;
@@ -234,7 +241,7 @@ string rigbase::to_binary(long freq, int len)
 	return bin;
 }
 
-long rigbase::fm_binary(char *binary, int len)
+long rigbase::fm_binary(string binary, int len)
 {
 	int i;
 	long f = 0;
@@ -245,7 +252,7 @@ long rigbase::fm_binary(char *binary, int len)
 	return f;
 }
 
-long rigbase::fm_binary_be(char *binary_be, int len)
+long rigbase::fm_binary_be(string binary_be, int len)
 {
 	unsigned char temp;
 	int numchars = len/2;
@@ -280,7 +287,7 @@ string rigbase::to_decimal(long d, int len)
 	return sdec;
 }
 
-long rigbase::fm_decimal(char *decimal, int len)
+long rigbase::fm_decimal(string decimal, int len)
 {
 	long d = 0;
 	for (int i = 0; i < len; i++) {
@@ -290,7 +297,7 @@ long rigbase::fm_decimal(char *decimal, int len)
 	return d;
 }
 
-long rigbase::fm_decimal_be(char *decimal_be, int len)
+long rigbase::fm_decimal_be(string decimal_be, int len)
 {
 	unsigned char temp;
 	int numchars = len/2;
@@ -303,6 +310,39 @@ long rigbase::fm_decimal_be(char *decimal_be, int len)
 	return fm_decimal(decimal_be, len);
 }
 
+//======================================================================
+// translation 0..255 <==> 0..100
+// for Icom controls
+//======================================================================
+
+static int set100[] =
+{  0,  3,  6,  8, 11, 13, 16, 18, 21, 23,
+  26, 29, 31, 34, 36, 39, 41, 44, 46, 49,
+  51, 54, 57, 59, 62, 64, 67, 69, 72, 74,
+  77, 80, 82, 85, 87, 90, 92, 95, 97,100,
+ 102,105,108,110,113,115,118,120,123,125,
+ 128,131,133,136,138,141,143,146,148,151,
+ 153,156,159,161,164,166,169,171,174,176,
+ 179,182,184,187,189,192,194,197,199,202,
+ 204,207,210,212,215,217,220,222,225,227,
+ 230,233,235,238,240,243,245,248,250,253,255};
+
+string rigbase::bcd255(int val)
+{
+	return to_bcd(set100[(int)(val)], 3);
+}
+
+int rigbase::num100(string bcd)
+{
+	int val = fm_bcd(bcd, 3);
+	for (int n = 0; n < 101; n++) {
+		if (set100[n] > val)  return n - 1;
+		if (set100[n] == val) return n;
+	}
+	return 0;
+}
+//======================================================================
+
 int rigbase::waitN(size_t n, int timeout, const char *sz, int pr)
 {
 	char sztemp[50];
@@ -311,12 +351,12 @@ int rigbase::waitN(size_t n, int timeout, const char *sz, int pr)
 	int cnt = 0;
 	int waited = 0;
 	size_t num = n + cmd.length();
-	int delay =  num * 11000.0 / RigSerial.Baud() +
+	int delay =  num * 11000.0 / RigSerial->Baud() +
 			progStatus.use_tcpip ? progStatus.tcpip_ping_delay : 0;
 
 	replystr.clear();
 
-	if(!progStatus.use_tcpip && !RigSerial.IsOpen()) {
+	if(!progStatus.use_tcpip && !RigSerial->IsOpen()) {
 		snprintf(sztemp, sizeof(sztemp), "TEST %s", sz);
 		showresp(WARN, pr, sztemp, tosend, replystr);
 		return 0;
@@ -358,12 +398,12 @@ int rigbase::wait_char(int ch, size_t n, int timeout, const char *sz, int pr)
 	int waited = 0;
 	size_t num = n + cmd.length();
 
-	int delay =  num * 11000.0 / RigSerial.Baud() +
+	int delay =  num * 11000.0 / RigSerial->Baud() +
 			progStatus.use_tcpip ? progStatus.tcpip_ping_delay : 0;
 
 	replystr.clear();
 
-	if(!progStatus.use_tcpip && !RigSerial.IsOpen()) {
+	if(!progStatus.use_tcpip && !RigSerial->IsOpen()) {
 		snprintf(sztemp, sizeof(sztemp), "TEST %s", sz);
 		showresp(report_level, pr, sztemp, tosend, replystr);
 		return 0;
