@@ -27,6 +27,7 @@
 #include <stdlib.h>
 #include <iostream>
 #include <fstream>
+#include <sstream>
 #include <vector>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -48,9 +49,12 @@
 
 using namespace XmlRpc;
 
+#include "tod_clock.h"
+
 // The server
 XmlRpcServer rig_server;
 
+extern bool xcvr_initialized;
 //------------------------------------------------------------------------------
 // Request for transceiver name
 //------------------------------------------------------------------------------
@@ -59,7 +63,10 @@ public:
 	rig_get_xcvr(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_xcvr", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		result = selrig->name_;
+		if (!xcvr_initialized)
+			result = "";
+		else
+			result = selrig->name_;
 	}
 
 	std::string help() { return std::string("returns noun name of transceiver"); }
@@ -154,7 +161,12 @@ public:
 	rig_get_info(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_info", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		string info;
+		string info = "";
+
+		if (!xcvr_initialized) {
+			result = info;
+			return;
+		}
 
 		uname = sname();   info.assign(uname);
 		utx = stx();       info.append(utx);
@@ -180,6 +192,11 @@ public:
 		string info;  info.clear();
 		string temp;  temp.clear();
 
+		if (!xcvr_initialized) {
+			result = info;
+			return;
+		}
+
 		if (selrig->has_smeter && !btnPTT->value()) {
 			static char szval[10];
 			snprintf(szval, sizeof(szval), "S:%d\n", (int)mval);
@@ -219,7 +236,7 @@ public:
 	rig_get_ptt(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_ptt", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		result = btnPTT->value();
+		result = int(PTT);
 	}
 
 	std::string help() { return std::string("returns state of PTT"); }
@@ -235,6 +252,11 @@ public:
 	rig_get_vfo(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_vfo", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		if (!xcvr_initialized) {
+			result = "14070000";
+			return;
+		}
+
 		static char szfreq[20];
 		int freq;
 		if (useB) {
@@ -264,7 +286,10 @@ public:
 	rig_get_AB(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_AB", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-//		result[0] = useB ? "B" : "A";
+		if (!xcvr_initialized) {
+			result = "A";
+			return;
+		}
 		result = useB ? "B" : "A";
 	}
 
@@ -282,11 +307,15 @@ public:
 	rig_get_notch(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_notch", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		if (!xcvr_initialized) {
+			result = 0;
+			return;
+		}
 
-	if (progStatus.notch)
-		result = (int)(progStatus.notch_val);
-	else
-		result = (int)0;
+		if (progStatus.notch)
+			result = (int)(progStatus.notch_val);
+		else
+			result = (int)0;
 	}
 
 	std::string help() { return std::string("returns notch value"); }
@@ -301,9 +330,14 @@ public:
 	rig_set_notch(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_notch", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		if (!xcvr_initialized) {
+			result = 0;
+			return;
+		}
+
 		static int ntch;
 		ntch = static_cast<int>((double)(params[0]));
-		progStatus.notch_val = ntch;
+		if (ntch) progStatus.notch_val = ntch;
 		if (ntch)
 			progStatus.notch = true;
 		else
@@ -327,16 +361,20 @@ public :
 	rig_get_modes(XmlRpcServer *s) : XmlRpcServerMethod("rig.get_modes", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		XmlRpcValue modes;
 
-		if (!selrig->modes_) {
-			result = "none";
+		if (!xcvr_initialized || !selrig->modes_) {
+			modes[0] = "CW";
+			modes[1] = "LSB";
+			modes[2] = "USB";
 			return;
 		}
-		XmlRpcValue modes;
+
 		int i = 0;
 		for (const char** mode = selrig->modes_; *mode; mode++, i++)
 			modes[i] = *mode;
 		result = modes;
+
 		}
 
 	std::string help() { return std::string("returns list of modes"); }
@@ -352,6 +390,12 @@ public:
 	rig_get_sideband(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_sideband", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+
+		if (!xcvr_initialized) {
+			result = "U";
+			return;
+		}
+
 		int mode;
 		if (useB) {
 			guard_lock queB_lock(&mutex_queB);
@@ -365,6 +409,7 @@ public:
 		std::string result_string = "";
 		result_string += selrig->get_modetype(mode);
 		result = result_string;
+
 	}
 
 	std::string help() { return std::string("returns current xcvr sideband (U/L)"); }
@@ -380,6 +425,11 @@ public:
 	rig_get_mode(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_mode", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		if (!xcvr_initialized) {
+			result = "USB";
+			return;
+		}
+
 		int mode;
 		if (useB) {
 			guard_lock queB_lock(&mutex_queB);
@@ -393,6 +443,7 @@ public:
 		std::string result_string = "none";
 		if (selrig->modes_) result_string = selrig->modes_[mode];
 		result = result_string;
+
 	}
 
 	std::string help() { return std::string("returns current xcvr mode"); }
@@ -409,8 +460,11 @@ public :
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
 
-		if (!selrig->bandwidths_) {
-			result = "none";
+		if (!xcvr_initialized || !selrig->bandwidths_) {
+			XmlRpcValue bws;
+			bws[0][0] = "Bandwidth";
+			bws[0][1] = "NONE";
+			result = bws;
 			return;
 		}
 		XmlRpcValue bws;
@@ -451,6 +505,7 @@ public :
 				n++; i++;
 			}
 		}
+
 		result = bws;
 	}
 
@@ -467,28 +522,51 @@ public:
 	rig_get_bw(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_bw", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+
+		result[0] = "NONE";
+		result[1] = "";
+
+		if (!xcvr_initialized) return;
+
 		{
 			guard_lock queA_lock(&mutex_queA);
 			guard_lock queB_lock(&mutex_queB);
-			if (! queA.empty() || !queB.empty()) {
-				result[0] = "";
-				result[1] = "";
-				return;
-			}
+			if (! queA.empty() || !queB.empty()) return;
 		}
 
 		int BW = useB ? vfoB.iBW : vfoA.iBW;
 		int mode = useB ? vfoB.imode : vfoA.imode;
+
 		const char **bwt = selrig->bwtable(mode);
 		const char **dsplo = selrig->lotable(mode);
 		const char **dsphi = selrig->hitable(mode);
-//std::cout << "BW " << std::hex << BW << std::dec << "\n";
-		result[0] = (BW > 256 && selrig->has_dsp_controls) ?
-					(dsplo ? dsplo[BW & 0x7F] : "") : 
-					(bwt ? bwt[BW] : "");
-		result[1] = (BW > 256 && selrig->has_dsp_controls) ?
-					(dsphi ? dsphi[(BW >> 8) & 0x7F] : "") : 
-					"";
+
+		int max_bwt = 0,
+			max_lotable = 0,
+			max_hitable = 0;
+		if (bwt)   while (bwt[max_bwt] != NULL) max_bwt++;
+		if (dsplo) while (dsplo[max_lotable] != NULL) max_lotable++;
+		if (dsphi) while (dsphi[max_hitable] != NULL) max_hitable++;
+
+		result[0] = result[1] = "";
+		if (BW < 256 && bwt) {
+			int SB = BW & 0x7F;
+			if (SB < 0) SB = 0;
+			if (SB > max_bwt) SB = max_bwt-1;
+			result[0] = bwt[SB];
+		}
+		else if (dsplo && dsphi) {
+			int SL = BW & 0x7F;
+			if (SL >= max_lotable) SL = max_lotable - 1;
+			if (SL < 0) SL = 0;
+
+			int SH = (BW >> 8) & 0x7F;
+			if (SH >= max_hitable) SH = max_hitable - 1;
+			if (SH < 0) SH = 0;
+
+			if (dsplo) result[0] = dsplo[SL];
+			if (dsphi) result[1] = dsphi[SH];
+		}
 	}
 
 	std::string help() { return std::string("returns current bw L/U value"); }
@@ -501,7 +579,7 @@ public:
 	rig_get_smeter(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_smeter", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!selrig->has_smeter) 
+		if (!xcvr_initialized || !selrig->has_smeter) 
 			result = (int)(0);
 		else
 			result = (int)(mval);
@@ -514,7 +592,7 @@ public:
 	rig_get_pwrmeter(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_pwrmeter", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
-		if (!selrig->has_power_out) 
+		if (!xcvr_initialized || !selrig->has_power_out) 
 			result = (int)(0);
 		else
 			result = (int)(mval);
@@ -528,15 +606,14 @@ public:
 #include <queue>
 #include "rigbase.h"
 
-extern char *print(FREQMODE);
-extern queue<FREQMODE> queA;
-extern queue<FREQMODE> queB;
+extern queue<XCVR_STATE> queA;
+extern queue<XCVR_STATE> queB;
 extern queue<bool> quePTT;
 
-extern FREQMODE vfoA;
-extern FREQMODE vfoB;
+extern XCVR_STATE vfoA;
+extern XCVR_STATE vfoB;
 
-FREQMODE srvr_vfo;
+XCVR_STATE srvr_vfo;
 
 static void push_xml()
 {
@@ -547,7 +624,6 @@ static void push_xml()
 		srvr_vfo.imode,
 		(srvr_vfo.iBW / 256),
 		(srvr_vfo.iBW & 0xFF));
-//std::cout << pr << "\n";
 	LOG_DEBUG("%s", pr);
 	if (useB) {
 		guard_lock gl_xmlqueB(&mutex_queB, 101);
@@ -566,7 +642,13 @@ public:
 	rig_set_ptt(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_ptt", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		if (!xcvr_initialized) {
+			result = 0;
+			return;
+		}
 		int state = int(params[0]);
+
+//std::cout << "set ptt" << state << std::endl;
 		if (state) Fl::awake(setPTT, (void *)1);
 		else Fl::awake(setPTT, (void *)0);
 	}
@@ -593,7 +675,14 @@ public:
 	rig_set_AB(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_AB", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		if (!xcvr_initialized) {
+			result = 0;
+			return;
+		}
 		std::string ans = std::string(params[0]);
+
+//std::cout << "select vfo " << ans << std::endl;
+
 		if (ans == "A" && useB) Fl::awake(selectA);
 		if (ans == "B" && !useB) Fl::awake(selectB);
 	}
@@ -611,17 +700,43 @@ public:
 	rig_set_vfo(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_vfo", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		if (!xcvr_initialized) {
+			result = 0;
+			return;
+		}
 		long freq = static_cast<long>(double(params[0]));
 // set the frequency in vfoA or vfoB
 		if (useB) srvr_vfo = vfoB;
 		else       srvr_vfo = vfoA;
 		srvr_vfo.freq = freq;
+//std::cout << "set vfo " << freq << std::endl;
 		push_xml();
 	}
 	std::string help() { return std::string("rig.set_vfo NNNNNNNN (Hz)"); }
 
 } rig_set_vfo(&rig_server);
 
+class main_set_frequency : public XmlRpcServerMethod {
+public:
+	main_set_frequency(XmlRpcServer* s) : XmlRpcServerMethod("main.set_frequency", s) {}
+
+	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		if (!xcvr_initialized) {
+			result = 0;
+			return;
+		}
+		long freq = static_cast<long>(double(params[0]));
+// set the frequency in vfoA or vfoB
+		if (useB) srvr_vfo = vfoB;
+		else       srvr_vfo = vfoA;
+		srvr_vfo.freq = freq;
+//std::cout << "set freq " << freq << std::endl;
+
+		push_xml();
+	}
+	std::string help() { return std::string("main.set_frequency NNNNNNNN (Hz)"); }
+
+} main_set_frequency(&rig_server);
 
 //------------------------------------------------------------------------------
 // Set mode
@@ -632,6 +747,10 @@ public:
 	rig_set_mode(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_mode", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue &result) {
+		if (!xcvr_initialized) {
+			result = 0;
+			return;
+		}
 		if (useB) {
 			guard_lock queB_lock(&mutex_queB);
 			if (!queB.empty()) srvr_vfo = queB.back();
@@ -643,17 +762,21 @@ public:
 		}
 		std::string numode = string(params[0]);
 		int i = 0;
-		if (!selrig->modes_) return;
+
+		if (!selrig->modes_) {
+			return;
+		}
 		if (numode == selrig->modes_[srvr_vfo.imode]) return;
 		while (selrig->modes_[i] != NULL) {
 			if (numode == selrig->modes_[i]) {
 				srvr_vfo.imode = i;
-				srvr_vfo.iBW = 0;
+				srvr_vfo.iBW = selrig->def_bandwidth(i);
 				push_xml();
 				break;
 			}
 			i++;
 		}
+//std::cout << "set mode\n";
 	}
 	std::string help() { return std::string("set_mode MODE_NAME"); }
 
@@ -669,6 +792,10 @@ public:
 	rig_set_bw(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_bw", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		if (!xcvr_initialized) {
+			result = 0;
+			return;
+		}
 		int bw = int(params[0]);
 		if (useB) {
 			guard_lock queB_lock(&mutex_queB);
@@ -681,6 +808,7 @@ public:
 		}
 		srvr_vfo.iBW = bw;
 		push_xml();
+//std::cout << "set bw\n";
 	}
 	std::string help() { return std::string("set_bw to VAL"); }
 
@@ -691,9 +819,12 @@ public:
 	rig_set_BW(XmlRpcServer* s) : XmlRpcServerMethod("rig.set_BW", s) {}
 
 	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		if (!xcvr_initialized) {
+			result = 0;
+			return;
+		}
 		string bwstr = params;
-		std::cout << bwstr << "\n";
-/*
+
 		int bw = int(params[0]);
 		if (useB) {
 			guard_lock queB_lock(&mutex_queB);
@@ -706,7 +837,7 @@ public:
 		}
 		srvr_vfo.iBW = bw;
 		push_xml();
-*/
+
 	}
 	std::string help() { return std::string("set_bw to VAL"); }
 
@@ -735,7 +866,8 @@ struct MLIST {
 	{ "rig.set_mode",     "i:i", "set MODE iaw MODE table" },
 	{ "rig.set_notch",    "d:d", "set NOTCH value in Hz" },
 	{ "rig.set_ptt",      "i:i", "set PTT 1/0 (on/off)" },
-	{ "rig.set_vfo",      "d:d", "set current VFO in Hz" }
+	{ "rig.set_vfo",      "d:d", "set current VFO in Hz" },
+	{ "main.set_frequency",      "d:d", "set current VFO in Hz" }
 };
 
 class rig_list_methods : public XmlRpcServerMethod {
