@@ -351,111 +351,6 @@ void cbUSBaudio()
 	progStatus.USBaudio = btnUSBaudio->value();
 }
 
-void cbCancelXcvrDialog()
-{
-	btnOkXcvrDialog->labelcolor(FL_BLACK);
-	dlgXcvrConfig->hide();
-}
-
-void cbOkXcvrDialog()
-{
-	if (progStatus.UIsize == wide_ui) {
-		btn_show_controls->label("@-22->");
-		btn_show_controls->redraw_label();
-		grpTABS->hide();
-		mainwindow->resizable(grpTABS);
-		mainwindow->size(mainwindow->w(), 150);
-		mainwindow->size_range(735, 150, 0, 150);
-	}
-
-	// close the current rig control
-	closeRig();               // local serial comm connection
-//	disconnect_from_remote(); // remote tcpip connection
-
-	{ guard_lock gl_serial(&mutex_serial, 200);
-		RigSerial.ClosePort();
-		AuxSerial.ClosePort();
-		SepSerial.ClosePort();
-		bypass_serial_thread_loop = true;
-	}
-
-	string p1 = selectCommPort->value();
-	string p2 = selectAuxPort->value();
-	string p3 = selectSepPTTPort->value();
-
-	if (p1.compare("NONE") != 0)
-		if (p1 == p2 || p1 == p3) {
-			fl_message("Select separate ports");
-			return;
-		}
-
-	if (p2.compare("NONE") != 0)
-		if (p2 == p3) {
-			fl_message("Select separate ports");
-			return;
-		}
-
-	if (xcvr_name != rigs[selectRig->index()]->name_) {
-		clearList();
-		saveFreqList();
-		selrig = rigs[selectRig->index()];
-		xcvr_name = selrig->name_;
-	}
-
-	progStatus.xcvr_serial_port = selectCommPort->value();
-	progStatus.aux_serial_port = selectAuxPort->value();
-	progStatus.sep_serial_port = selectSepPTTPort->value();
-
-	progStatus.comm_baudrate = mnuBaudrate->index();
-	progStatus.stopbits = btnOneStopBit->value() ? 1 : 2;
-	progStatus.comm_retries = (int)cntRigCatRetries->value();
-	progStatus.comm_timeout = (int)cntRigCatTimeout->value();
-	progStatus.comm_wait = (int)cntRigCatWait->value();
-	progStatus.comm_echo = btnRigCatEcho->value();
-	progStatus.comm_rtsptt = btnrtsptt->value();
-	progStatus.comm_catptt = btncatptt->value();
-	progStatus.comm_dtrptt = btndtrptt->value();
-	progStatus.comm_rtscts = chkrtscts->value();
-	progStatus.comm_rtsplus = btnrtsplus->value();
-	progStatus.comm_dtrplus = btndtrplus->value();
-
-	progStatus.sep_dtrplus = btnSepDTRplus->value();
-	progStatus.sep_dtrptt = btnSepDTRptt->value();
-	progStatus.sep_rtsplus = btnSepRTSplus->value();
-	progStatus.sep_rtsptt = btnSepRTSptt->value();
-
-	progStatus.imode_B  = progStatus.imode_A  = selrig->def_mode;
-	progStatus.iBW_B    = progStatus.iBW_A    = selrig->def_bw;
-	progStatus.freq_B   = progStatus.freq_A   = selrig->def_freq;
-
-	init_title();
-
-	if (!startXcvrSerial()) {
-		if (progStatus.xcvr_serial_port.compare("NONE") == 0) {
-			LOG_WARN("No comm port ... test mode");
-		} else {
-			progStatus.xcvr_serial_port = "NONE";
-			selectCommPort->value(progStatus.xcvr_serial_port.c_str());
-		}
-	}
-	if (!startAuxSerial()) {
-		if (progStatus.aux_serial_port.compare("NONE") != 0) {
-			progStatus.aux_serial_port = "NONE";
-			selectAuxPort->value(progStatus.aux_serial_port.c_str());
-		}
-	}
-	if (!startSepSerial()) {
-		if (progStatus.sep_serial_port.compare("NONE") != 0) {
-			progStatus.sep_serial_port = "NONE";
-			selectSepPTTPort->value(progStatus.sep_serial_port.c_str());
-		}
-	}
-
-	initRig();
-
-	btnOkXcvrDialog->labelcolor(FL_BLACK);
-}
-
 void configXcvr()
 {
 
@@ -494,6 +389,12 @@ void open_poll_tab()
 	tabsConfig->value(tabPolling);
 }
 
+void open_restore_tab()
+{
+	dlgXcvrConfig->show();
+	tabsConfig->value(tabRestore);
+}
+
 void open_send_command_tab()
 {
 	dlgXcvrConfig->show();
@@ -506,11 +407,11 @@ void open_tcpip_tab()
 	tabsConfig->value(tabTCPIP);
 }
 
-void open_xmlrpc_tab()
-{
-	dlgXcvrConfig->show();
-	tabsConfig->value(tabXMLRPC);
-}
+//void open_xmlrpc_tab()
+//{
+//	dlgXcvrConfig->show();
+//	tabsConfig->value(tabXMLRPC);
+//}
 
 void open_ptt_tab()
 {
@@ -534,11 +435,11 @@ void createXcvrDialog()
 	for (int i = 0; szBaudRates[i] != NULL; i++)
 		mnuBaudrate->add(szBaudRates[i]);
 
-	cbo_agc_level->clear();
-	cbo_agc_level->add("slow");
-	cbo_agc_level->add("med");
-	cbo_agc_level->add("fast");
-	cbo_agc_level->index(progStatus.agc_level);
+//	cbo_agc_level->clear();
+//	cbo_agc_level->add("slow");
+//	cbo_agc_level->add("med");
+//	cbo_agc_level->add("fast");
+//	cbo_agc_level->index(progStatus.agc_level);
 
 	cbo_tt550_agc_level->add("slow");
 	cbo_tt550_agc_level->add("med");
@@ -1154,8 +1055,8 @@ void show_controls()
 				btn_show_controls->label("@-28->");
 				btn_show_controls->redraw_label();
 				mainwindow->resizable(grpTABS);
-				mainwindow->size(mainwindow->w(), 218);
-				mainwindow->size_range(735, 218, 0, 218);
+				mainwindow->size(mainwindow->w(), 220);
+				mainwindow->size_range(735, 220, 0, 220);
 				grpTABS->show();
 			}
 			mainwindow->redraw();
@@ -1173,35 +1074,47 @@ void show_controls()
 			mainwindow->redraw();
 			return;
 		case small_ui :
+			{
+				int wh = mainwindow->h();
+				int ww = mainwindow->w();
 			if (selrig->name_ == rig_TT550.name_) {
 				tabsGeneric->hide();
 				if (tabs550->visible()) {
 					tabs550->hide();
 					btn_show_controls->label("@-22->");
 					btn_show_controls->redraw_label();
-					mainwindow->size( mainwindow->w(), mainwindow->h() - 70);
+					wh -= 70;
+					mainwindow->resizable(grpTABS);
+					mainwindow->size( ww, wh);
 				} else {
 					tabs550->show();
 					btn_show_controls->label("@-28->");
 					btn_show_controls->redraw_label();
-					mainwindow->size( mainwindow->w(), mainwindow->h() + 70);
+					wh += 70;
+					mainwindow->resizable(grpTABS);
+					mainwindow->size( ww, wh);
 				}
-				mainwindow->redraw();
 			} else {
 				tabs550->hide();
 				if (tabsGeneric->visible()) {
 					tabsGeneric->hide();
 					btn_show_controls->label("@-22->");
 					btn_show_controls->redraw_label();
-					mainwindow->size( mainwindow->w(), mainwindow->h() - 70);
+					wh -= 70;
+					mainwindow->size( ww, wh);
+					mainwindow->size_range(ww, wh, ww, wh);
 				} else {
 					tabsGeneric->show();
 					btn_show_controls->label("@-28->");
 					btn_show_controls->redraw_label();
-					mainwindow->size( mainwindow->w(), mainwindow->h() + 70);
+					wh += 70;
+					mainwindow->size( ww, wh);
+					mainwindow->size_range(ww, wh, ww, wh);
 				}
-				mainwindow->redraw();
 			}
+		}
+			grpTABS->show();
+			mainwindow->redraw();
 			break;
 		default :
 			break;
@@ -1477,10 +1390,10 @@ Fl_Color flrig_def_color(int n)
 }
 
 
-void cb_send_command()
+void cb_send_command(string command, Fl_Output *resp)
 {
+	if (command.empty()) return;
 	bool usehex = false;
-	string command = txt_command->value();
 	if (command.empty()) return;
 	string cmd = "";
 	if (command.find("x") != string::npos) { // hex strings
@@ -1497,6 +1410,11 @@ void cb_send_command()
 // lock out polling loops until done
 	guard_lock gl_serial(&mutex_serial, 201);
 
+	if (resp) {
+		resp->value("");
+		resp->redraw();
+	}
+
 	sendCommand(cmd, 0);
 
 	int timeout = 1000;
@@ -1508,7 +1426,10 @@ void cb_send_command()
 	}
 
 	readResponse();
-	txt_response->value(
-		usehex ? str2hex(replystr.c_str(), replystr.length()) :
-		replystr.c_str());
+	if (resp) {
+		resp->value(
+			usehex ? str2hex(replystr.c_str(), replystr.length()) :
+			replystr.c_str());
+		resp->redraw();
+	}
 }
